<?php
if(!class_exists('DukaPress_PDF')) {
    
    define('FPDF_FONTPATH', DPSC_DUKAPRESS_LIB_DIR.'/fpdf16/font/');
    require_once(DPSC_DUKAPRESS_LIB_DIR.'/fpdf16/fpdf.php');
    
    class DPSC_PDF extends FPDF {

        //Page header
        function Header() {
            global $dukapress;
            $ad = array();
            $ad['f_name'] = $dukapress->get_setting( 'shop_name' );
            $ad['street'] = $dukapress->get_setting( 'shop_address' );
            $ad['zip'] = $dukapress->get_setting( 'shop_zip' );
            $ad['town'] = $dukapress->get_setting( 'shop_city' );
            $ad['state'] = $dukapress->get_setting( 'shop_state' );


            $biz_ad = implode("<br/>", $ad);
            $biz = str_replace("<br/>", "\n", $biz_ad);
            $biz = DukaPress_PDF::pdf_encode($biz);

            $this->SetFont('Arial', 'B', 12);

            //$url  = get_option('siteurl');
            $path = DPSC_DUKAPRESS_RESOURCEDIR . '/img/pdf-logo-1.jpg';
            $this->Image($path);
            $this->SetXY(90, 7);
            $this->MultiCell(0, 7, "$biz", 0, 'L');
        }

        //Page footer
        function Footer() {
            global $dukapress;
            //Position at xy mm from bottom
            $this->SetY(-25);
            //Arial italic 6
            $this->SetFont('Arial', '', 6);

            if (FALSE) {
                $vat_id = ' - ' . get_option('wps_vat_id_label') . ': ' . get_option('wps_vat_id');
            } else {$vat_id = NULL;        }
            $shop_name = $dukapress->get_setting( 'shop_name' );
            $footer_text = $shop_name . $vat_id;
            $this->Cell(0, 10, "$footer_text", 1, 0, 'C');
        }

    }
    
    /**
     * Handle All PDF Creations
     *
     */
    class DukaPress_PDF{
        
        /**
         * Make PDF
         * @param $order_id - The ID of the order
         * @param $meta - The meta information of the order
         *
         */
        static function make_pdf($order_id) {
 
            global $dukapress;
            
            $order = $dukapress->get_order($order_id);
            
            $meta = get_post_custom($order->ID);
            //unserialize
            foreach ($meta as $key => $val)
                $meta[$key] = array_map('maybe_unserialize', $val);

            //Instanciation of inherited class
            $pdf = new DPSC_PDF();
            $pdf->SetLeftMargin(10);
            $pdf->SetRightMargin(10);
            $pdf->SetTopMargin(5);

            // widths of columns
            $w1 = 20;
            $w2 = 64;
            $w3 = 30;
            $w4 = 38;
            $w5 = 38;

            $h2 = 3;


            $pdf->AddPage();
            $pdf->Ln(20);
            $pdf->SetFont('Arial', '', 10);
            // data for address
            $order = array();
            
            $fnames = "";
            $address = "";
            $country = "";
            $state = "";
            
            $item_index =  array_search('dpsc_firstname', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $fnames = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            $item_index =  array_search('dpsc_lastname', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $fnames  .= " ".$meta["dpsc_user_info"][0][$item_index]['value'];
            }
            
            $item_index =  array_search('dpsc_address', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $address  = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            
            $item_index =  array_search('dpsc_country', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $country  = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            
            $item_index =  array_search('dpsc_state', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $state  = $meta["dpsc_user_info"][0][$item_index]['value'];
            }

            
            $order['f_name'] = $fnames;
            $order['street'] = $address;
            $order['country'] = $country;
            $order['state'] = $state;

            self::address_format($order, 'pdf_cust_address', $pdf);
            
            $phone = "";
            $item_index =  array_search('dpsc_phone', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $phone = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            
            $pdf->Ln(20);
            $pdf->SetFont('Arial', 'B', 10);
            $phone_no = self::pdf_encode('Contact No. : ' . $phone);
            $pdf->Cell(0, 6, $phone_no, 0, 1);
            $bill_no = self::pdf_encode('Bill No. : ' . $order_id);
            $pdf->Cell(0, 6, $bill_no, 0, 1);

            $pdf->SetFont('Arial', '', 8);
            $pdf->Cell(0, 4, date(get_option('date_format')), 0, 1, 'R');

            $pdf->Ln(5);
            $pdf->SetFont('Arial', 'B', 9);
            $pdf->Cell($w1, 6, self::pdf_encode('Sr. No.'), 1, 0);
            $pdf->Cell($w2, 6, self::pdf_encode('Product Name'), 1, 0);
            $pdf->Cell($w3, 6, self::pdf_encode('Quantity'), 1, 0);
            $pdf->Cell($w4, 6, self::pdf_encode('Product Price'), 1, 0);
            $pdf->Cell($w5, 6, self::pdf_encode('Total'), 1, 1);
            $pdf->SetFont('Arial', '', 9);


            // get the cart content again
            $cart = $meta["dpsc_cart_info"][0];
            $dpsc_total = 0.00;
            $count = 1;
            foreach ($cart as $key => $dpsc_product) {
                $product = get_post($dpsc_product['item_number']);
                $dpsc_var = '';
                if (!empty($dpsc_product['var'])) {
                    $dpsc_var = ' (' . $dpsc_product['var'] . ')';
                }
                $dpsc_total += $dpsc_product['price'] * $dpsc_product['quantity'];
                $dis_price = $dpsc_product['price'];
                $dis_price_total = $dpsc_product['price'] * $dpsc_product['quantity'];
                //$details = explode("|", $dpsc_var);

                //$pdf->SetFont('Arial', 'B', 9);

                //$pdf->Cell($w1, 6, self::pdf_encode("$details[5]"), 'LTR', 0); // Art-no
                //$pdf->Cell($w2, 6, self::pdf_encode("$details[2]"), 'LTR', 0); // Art-name
                //$pdf->Cell($w3, 6, self::pdf_encode("$details[1]"), 'LTR', 0); // Amount
                //$pdf->Cell($w4, 6, self::pdf_encode("$details[3]"), 'LTR', 0); // U - Price
                //$pdf->Cell($w5, 6, self::pdf_encode("$details[4]"), 'LTR', 1); // Total price
                // any attributes?
                $pdf->SetFont('Arial', '', 7);

                $pdf->Cell($w1, $h2, $count, 'LR', 0); // Art-no
                $pdf->Cell($w2, $h2, $product->post_title . $dpsc_var, 'LR', 0); // Art-name
                $pdf->Cell($w3, $h2, $dpsc_product['quantity'], 'LR', 0); // Amount
                $pdf->Cell($w4, $h2, self::pdf_encode($dukapress->format_currency( '',$dis_price,true)), 'LR', 0); // U - Price
                $pdf->Cell($w5, $h2, self::pdf_encode($dukapress->format_currency( '',$dis_price_total,true)), 'LR', 1); // Total price

                $pdf->Cell($w1, 1, "", 'LBR', 0); // Art-no
                $pdf->Cell($w2, 1, "", 'LBR', 0); // Art-name
                $pdf->Cell($w3, 1, "", 'LBR', 0); // Amount
                $pdf->Cell($w4, 1, "", 'LBR', 0); // U - Price
                $pdf->Cell($w5, 1, "", 'LBR', 1); // Total price
            }
            $pdf->SetFont('Arial', '', 9);


            $total = $dpsc_total;
            
            $dpsc_discount_value = 0;
            if (isset($meta["duka_discount_info"][0]) && $meta["duka_discount_info"][0]) {
                $dpsc_discount_value = $meta["duka_discount_info"][0]['discount'];
            }
            $tax = $meta["duka_tax_total"][0];
            $dpsc_shipping_value = 0;
            if(isset($meta["duka_shipping_total"]))
                $dpsc_shipping_value =  $meta["duka_shipping_total"][0];

            if ($dpsc_discount_value > 0) {
                $total_discount = $total * $dpsc_discount_value / 100;
            } else {
                $total_discount = 0.00;
            }
            if ($tax > 0) {
                $total_tax = ($total - $total_discount) * $tax / 100;
            } else {
                $total_tax = 0.00;
            }
            $shipping = $dpsc_shipping_value;
            $amount = $total + $shipping + $total_tax - $total_discount;
            $netsum_str = 'Subtotal:' . ' ' . $dukapress->format_currency( '',$total,true);
            $pdf->Cell(0, 6, self::pdf_encode($netsum_str), 0, 1, 'R');

            // discount
            $disf_str = self::pdf_encode('- Discount:') . ' ' .$dukapress->format_currency('',$total_discount,true);
            $pdf->Cell(0, 6, self::pdf_encode($disf_str), 0, 1, 'R');
            // discount
            $taxf_str = self::pdf_encode('+ Tax:') . ' ' . $dukapress->format_currency('',$total_tax,true);
            $pdf->Cell(0, 6, self::pdf_encode($taxf_str), 0, 1, 'R');
            // shipping fee
            $shipf_str = self::pdf_encode('+ Shipping fee:') . ' ' .$dukapress->format_currency('',$shipping,true);
            $pdf->Cell(0, 6, self::pdf_encode($shipf_str), 0, 1, 'R');


            $pdf->SetFont('Arial', 'B', 9);
            $totf_str = self::pdf_encode('Total:') . ' ' . $dukapress->format_currency('',$amount,true);
            $pdf->Cell(00, 6, self::pdf_encode($totf_str), 0, 1, 'R');

            $file_name = 'invoice_' . $order_id . '.pdf';
            $pdf->SetDisplayMode(100);
            $output_path = DPSC_PDF_CONTENT_DIR . '/' . $file_name;
            
            $pdf->Output($output_path, 'F');
        }
        
        /**
         * Encode PDF Values
         *
         */
        static function pdf_encode($data) {
            $data = mb_convert_encoding($data, "iso-8859-1", "auto");
            return $data;
        }
        
        /**
         * Format Address
         *
         */
        static function address_format($ad, $option='html', $pdf=0) {

            $address = NULL;
            $name = $ad['f_name'];
            if (strpos($address, 'NAME') !== false) {
                $address = str_replace("NAME", strtoupper($name), $address);
            }
            if (strpos($address, 'name') !== false) {
                $address = str_replace("name", $name, $address);
            }

            $address = self::address_token_replacer($address, 'STREET', $ad);
            $address = self::address_token_replacer($address, 'HSNO', $ad);
            $address = self::address_token_replacer($address, 'STRNO', $ad);
            $address = self::address_token_replacer($address, 'STRNAM', $ad);
            $address = self::address_token_replacer($address, 'PB', $ad);
            $address = self::address_token_replacer($address, 'PO', $ad);
            $address = self::address_token_replacer($address, 'PZONE', $ad);
            $address = self::address_token_replacer($address, 'CROSSSTR', $ad);
            $address = self::address_token_replacer($address, 'COLONYN', $ad);
            $address = self::address_token_replacer($address, 'DISTRICT', $ad);
            $address = self::address_token_replacer($address, 'REGION', $ad);
            $address = self::address_token_replacer($address, 'PLACE', $ad);
            $address = self::address_token_replacer($address, 'STATE', $ad);
            $address = self::address_token_replacer($address, 'ZIP', $ad);
            $address = self::address_token_replacer($address, 'COUNTRY', $ad);

            foreach ($ad as $p) {
                $pdf->Cell(0, 6, utf8_decode($p), 0, 1);
            }
            return $address;
        }

        /**
         * Replace Address items
         */
        static function address_token_replacer($address, $needle, $replace) {
            $needle_lower = strtolower($needle);
            $key = $needle_lower;
            if (($needle == 'PLACE') || ( $needle == 'place')) {
                $key = 'town';
            }

            if (stripos($address, $needle) !== false) {
                if (strpos($address, $needle) !== false) {
                    $address = str_replace($needle, mb_strtoupper($replace[$key]), $address);
                } else {
                    $address = str_replace($needle_lower, $replace[$key], $address);
                }
            }
            return $address;
        }
    }
}
?>