<?php
if (!class_exists('DukaPress')) {

    /**
     * Main DukaPress Class
     *
     * @class DukaPress
     * @since 2.6
     */
    class DukaPress{

        //Variables to be used
        var $version = '3.24';

        var $defaults = array('related_products' => array('product_id' => NULL, 'relate_by' => 'both', 'echo' => false, 'limit' => NULL, 'simple_list' => NULL));

        var $form_elements = array('Text' => 'text', 'Text Area' => 'textarea', 'Check Box' => 'checkbox', 'Paragraph' => 'paragraph');
        
        /**
        * @var The single instance of the class
        * @since 2.6
        */
        protected static $_instance = null;


        //Get instance
        public static function instance() {
          if ( is_null( self::$_instance ) ) {
             self::$_instance = new self();
          }
          return self::$_instance;
        }
        
        
        function __construct() {

            //setup our variables and load classes
            $this->init_dpsc();

            //Lets install
            add_action('wp_loaded', array(&$this, 'install'));

            //Call action when admin installs a new site
            add_action('wpmu_new_blog', array(&$this, 'setup_new_blog'), 10, 6);
            
            //localize the plugin
		    add_action( 'plugins_loaded', array( &$this, 'localization' ), 9 );

            //custom post type
            Dukapress_PostTypes::init();


             //super high priority
            add_filter('request', array(&$this, 'handle_edit_screen_filter'));
            add_filter('post_updated_messages', array(&$this, 'post_updated_messages'));

            //Columns
            Dukapress_PostColumns::init();

            //Admin Pages
            add_action('admin_menu', array(&$this, 'admin_menu'));
            add_action('admin_print_scripts', array(&$this, 'admin_script_post'));
            add_action('admin_notices', array(&$this, 'admin_nopermalink_warning'));
            add_filter('plugin_action_links_' . DPSC_BASENAME, array(&$this, 'plugin_action_link'), 10, 2);
			
			add_action( 'admin_bar_menu', array($this, 'admin_bar_menu'), 999 );

            //Meta boxes
            Dukapress_PostMeta::init();

            //Content filter
		    add_filter( 'the_content', array(&$this, 'content_filter' ) );

            //Rewrites
            add_filter('rewrite_rules_array', array(&$this, 'add_rewrite_rules'));
            add_filter('query_vars', array(&$this, 'add_queryvars'));
            add_action('option_rewrite_rules', array(&$this, 'check_rewrite_rules'));
            add_action('init', array(&$this, 'flush_rewrite_check'), 99);

            //Scripts and Styles
            add_action('wp_enqueue_scripts', array(&$this, 'set_up_styles'));
            add_action('wp_enqueue_scripts', array(&$this, 'set_up_js'));

            //Discounts
            add_action('wp_ajax_save_dpsc_discount_code', array(&$this, 'save_discount_code'));
            add_action('wp_ajax_dpsc_delete_discount_code', array(&$this, 'delete_discount_code'));
			
			//Get Product Price
			add_action('wp_ajax_nopriv_dpsc_format_price', array(&$this, 'format_price'));
			add_action('wp_ajax_dpsc_format_price', array(&$this, 'format_price'));

            //load APIs and plugins
            add_action('wp_loaded', array(&$this, 'load_plugins'));

            //Payment gateway returns
            add_action('pre_get_posts', array(&$this, 'handle_gateway_returns'), 1);
            
            //Cart
            DukaPress_Cart::init();

            //Downloads
            Dukapress_Downloads::init();
        }

        /**
         * Initialise the variables we need
         *
         * @since 2.6
         */
        function init_dpsc() {
            //Start the session
            $this->start_session();


            //Load Classes
            $this->load_class_resources(DPSC_DUKAPRESS_CLASSES_DIR);


            //Load helpers
            $this->load_class_resources(DPSC_DUKAPRESS_HELPERS_DIR);


            //Load includes
            $this->load_class_resources(DPSC_DUKAPRESS_INCLUDES_DIR);
			
			//Load Widgets
            $this->load_class_resources(DPSC_DUKAPRESS_WIDGETS_DIR);
            
            //Load Tools
            $this->load_class_resources(DPSC_DUKAPRESS_TOOLS_DIR);


            //Load Functions
            require_once (DPSC_DUKAPRESS_DIR . '/dukapress-functions.php');
        }

        /**
         * Set up new Multisite
         * @since 2.6
         */
        function setup_new_blog($blog_id, $user_id, $domain, $path, $site_id, $meta) {

            //flag to run on next visit to blog
            update_blog_option($blog_id, 'dukapress_do_install', 1);
        }

        /**
         * Begin installing
         * @since 2.6
         */
        function install() {
            if (!get_option('dukapress_do_install')) {
                if (get_option('dp_version') == $this->version) {
                    return;
                }
            }

            DukaPress_Install::init();
             //Initialise the options

            //add action to flush rewrite rules after we've added them for the first time
            update_option('dukapess_flush_rewrite', 1);

            update_option('dp_version', $this->version);
            delete_option('dukapress_do_install');
        }

        /*
         * Get settings array without undefined indexes
         * @param string $key A setting key, or -> separated list of keys to go multiple levels into an array
         * @param mixed $default Returns when setting is not set
         *
         * @since 2.6
        */
        function get_setting($key, $default = null) {
            $settings = get_option('dukapress_settings');
            $keys = explode('->', $key);
            array_map('trim', $keys);
            if (count($keys) == 1) 
				$setting = isset($settings[$keys[0]]) ? $settings[$keys[0]] : $default;
            else if (count($keys) == 2) 
				$setting = isset($settings[$keys[0]][$keys[1]]) ? $settings[$keys[0]][$keys[1]] : $default;
            else if (count($keys) == 3) 
				$setting = isset($settings[$keys[0]][$keys[1]][$keys[2]]) ? $settings[$keys[0]][$keys[1]][$keys[2]] : $default;
            else if (count($keys) == 4) 
				$setting = isset($settings[$keys[0]][$keys[1]][$keys[2]][$keys[3]]) ? $settings[$keys[0]][$keys[1]][$keys[2]][$keys[3]] : $default;

            return apply_filters("dukapress_setting_" . implode('', $keys), $setting, $default);
        }
        
        /**
         * Format Date
         */
        function format_date( $gmt_timestamp ) {
            return date_i18n( get_option( 'date_format' ) . ' - ' . get_option( 'time_format' ), $gmt_timestamp + ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS ) );
		}

        /**
         * Update Settings
         * @param string $key A setting key
         * @param mixed $value
         *
         * @since 2.6
         */
        function update_setting($key, $value) {
            $settings = get_option('dukapress_settings');
            $settings[$key] = $value;
            return update_option('dukapress_settings', $settings);
        }
        
        /**
         * Get Countries
         */ 
        function get_countries($countries = false, $code  = false, $name  = false){
            $countries = $this->country_code_name;
            return apply_filters('get_countries', $countries, $code, $name);
        }
        

        /**
         * Starts the Session
         * @since 2.6
         */
        function start_session() {
            $sess_id = session_id();

            if (empty($sess_id)) {
                session_start();
            }
        }

        /**
         * Load Files
         *
         */
        private function load_files($pattern, $flags = 0) {
            $files = glob($pattern, $flags); 
            foreach (glob(dirname($pattern).'/*', GLOB_ONLYDIR|GLOB_NOSORT) as $dir) {
                $files = array_merge($files, $this->load_files($dir.'/'.basename($pattern), $flags));
            }
            return $files;
        }

        /**
         * Load classes and files needed
         *
         *
         */
        function load_class_resources($dir) {

            $ext = '.php';

            $dir = trailingslashit( $dir );

            $pattern = $dir . '*' . $ext;
            $flags = 0;

            $class_resources = $this->load_files($pattern, $flags); 

            sort($class_resources);

            //include them suppressing errors
            foreach ($class_resources as $file) {
                require_once ($file);
            }
        }

        /**
         * Load Plugins
         * @since 2.6
         */
        function load_plugins() {
            if (is_network_admin() || !$this->get_setting('disable_cart')) {
                require_once (DPSC_DUKAPRESS_CLASSES_DIR . '/dukapress-gateway.php');
                $this->load_gateway_plugins();
            }
        }

        /**
         * Load Gateway Plugins
         * @since 2.6
         */
        function load_gateway_plugins() {

            //get gateway plugins dir
            $dir = DPSC_DUKAPRESS_GATEWAY_DIR;

            $ext = '.php';

            $dir = trailingslashit( $dir );

            $pattern = $dir . '*' . $ext;
            $flags = 0;

            $gateway_plugins = $this->load_files($pattern, $flags); 

            //include them suppressing errors
            foreach ($gateway_plugins as $file) {
                require_once ($file);
                $fp = fopen($file, 'r');
                $class = $buffer = '';
                $i = 0;
                while (!$class) {
                    if (feof($fp)) break;


                    $buffer.= fread($fp, 512);
                    if (preg_match('/class\s+(\w+)(.*)?\{/', $buffer, $matches)) {
                        $classes[] = $matches[1];
                        break;
                    }
                }
            }

            //Instantiate classes
            foreach ($classes as $class) {
                $c = new $class();
            }

            //allow plugins from an external location to register themselves
            do_action('dukapress_load_gateway_plugins');
        }

        /**
         * Format Currency
         *
         */
        function format_currency($currency = '', $amount = false, $decode = false) {
            
            if (!$currency)
              $currency = $this->get_setting('shop_currency', 'USD');

            // get the currency symbol
            $symbol = $this->currencies[$currency][1];

            // if many symbols are found, rebuild the full symbol
            $symbols = explode(', ', $symbol);
            if (is_array($symbols)) {
                $symbol = "";
                foreach ($symbols as $temp) {
                    $symbol.= '&#x' . $temp . ';';
                }
            }
            else {
                $symbol = '&#x' . $symbol . ';';
            }
            if($decode){
                $symbol = utf8_decode($symbol);
            }

            //check decimal option
            if ($this->get_setting('curr_decimal') === '0') {
                $decimal_place = 0;
                $zero = '0';
            }
            else {
                $decimal_place = 2;
                $zero = '0.00';
            }

            //format currency amount according to preference
            if ($amount) {
                if(is_numeric($amount)){
                    if ($this->get_setting('shop_currency_position') == 1 || !$this->get_setting('shop_currency_position'))
                      return $symbol . number_format_i18n($amount, $decimal_place);
                    else if ($this->get_setting('shop_currency_position') == 2)
                      return $symbol . ' ' . number_format_i18n($amount, $decimal_place);
                    else if ($this->get_setting('shop_currency_position') == 3)
                      return number_format_i18n($amount, $decimal_place) . $symbol;
                    else if ($this->get_setting('shop_currency_position') == 4)
                      return number_format_i18n($amount, $decimal_place) . ' ' . $symbol;
                }else{
                    return $amount;
                }
            }
            else if ($amount === false) {
                return $symbol;
            }
            else {
                if ($this->get_setting('shop_currency_position') == 1 || !$this->get_setting('shop_currency_position')) return $symbol . $zero;
                else if ($this->get_setting('shop_currency_position') == 2) return $symbol . ' ' . $zero;
                else if ($this->get_setting('shop_currency_position') == 3) return $zero . $symbol;
                else if ($this->get_setting('shop_currency_position') == 4) return $zero . ' ' . $symbol;
            }
        }
		
		/**
		 * Return the formated price via ajax
		 * 
		 */
		function format_price(){
			$price = $_POST['price'];
			if($price){
				echo __('Price: ','dp-lang').$this->format_currency('',$price);
			}else{
				echo __('Price: ','dp-lang').$this->format_currency('',0);
			}
			die();
		}

        /**
         * Register gateways
         * @param String $class_name
         * @param String $plugin_name
         * @param String $plugin_slug
         * @return null
         */
        function register_gateway($class_name, $plugin_name, $plugin_slug) {
            $dpsc_gateway_plugins = get_option('dpsc_gateway_plugins');

            if (!is_array($dpsc_gateway_plugins)) {
                $dpsc_gateway_plugins = array();
            }

            if (class_exists($class_name)) {
                $dpsc_gateway_plugins[$plugin_slug] = array($class_name, $plugin_name, $plugin_slug);
                update_option('dpsc_gateway_plugins', $dpsc_gateway_plugins);
            } 
            $dpsc_gateway_plugins_refreshed = array();
            $remove_gateways = array();
            foreach ($dpsc_gateway_plugins as $dpsc_gateway) {
                if (class_exists($dpsc_gateway[0])) {
                    $dpsc_gateway_plugins_refreshed[$dpsc_gateway[2]] = $dpsc_gateway;
                }else{
                    $remove_gateways[] = $dpsc_gateway[2];
                }
            }
            update_option('dpsc_gateway_removed_plugins', $remove_gateways);
            update_option('dpsc_gateway_plugins', $dpsc_gateway_plugins_refreshed);
        }
        
        function localization(){
            $lang_dir	 = DPSC_DUKAPRESS_LANGUAGE_DIR;
            $custom_path = WP_LANG_DIR . '/dukapress/dukapress-' . get_locale() . '.mo';
            $mu_plugins	 = wp_get_mu_plugins();
            if ( file_exists( $custom_path ) ) {
                load_textdomain( 'dp-lang', $custom_path );
            } elseif ( in_array( DPSC_PLUGIN_BASENAME, $mu_plugins ) ) {
                load_muplugin_textdomain( 'dp-lang', $lang_dir );
            } else {
                load_plugin_textdomain( 'dp-lang', false, $lang_dir );
            }
        }

        /**
         * IPN Returns
         */
        function handle_gateway_returns($wp_query) {
            if (is_admin()) return;

            //listen for gateway IPN returns and tie them in to proper gateway plugin
            if (!empty($wp_query->query_vars['paymentgateway'])) {
                do_action('dpsc_payment_return_' . $wp_query->query_vars['paymentgateway']);
            }
        }




        // This function clears the rewrite rules and forces them to be regenerated
        function flush_rewrite_check() {
            if (get_option('duka_flush_rewrite')) {
                flush_rewrite_rules();
                delete_option('duka_flush_rewrite');
            }
        }

        function add_rewrite_rules($rules) {
            $new_rules = array();

            //product list
            $new_rules[$this->get_setting('slugs->products') . '/?$'] = 'index.php?pagename=product_list';
            $new_rules[$this->get_setting('slugs->products') . '/page/?([0-9]{1,})/?$'] = 'index.php?pagename=product_list&paged=$matches[1]';

            //ipn handling for payment gateways
            $new_rules['payment-return/(.+)'] = 'index.php?paymentgateway=$matches[1]';
            
            //Downloads
            $new_rules['download/(.+)'] = 'index.php?paymentgateway=$matches[1]';

            return array_merge($new_rules, $rules);
        }

        //unfortunately some plugins flush rewrites before the init hook so they kill custom post type rewrites. This function verifies they are in the final array and flushes if not
        function check_rewrite_rules($value) {

            //prevent an infinite loop by only
            if (!post_type_exists('duka')) return $value;

            if (is_array($value) && !in_array('index.php?duka=$matches[1]&paged=$matches[2]', $value)) {
                update_option('duka_flush_rewrite', 1);
            }
            else {
                return $value;
            }
        }

        function add_queryvars($vars) {

            if (!in_array('paymentgateway', $vars)) 
                $vars[] = 'paymentgateway';

            return $vars;
        }

        function admin_nopermalink_warning() {
      		//warns admins if permalinks are not enabled on the blog
      		if ( current_user_can( 'manage_options' ) && !get_option( 'permalink_structure' ) )
      			echo '<div class="error"><p>' . __( 'DukaPress requires Pretty Permalinks to work. <a href="options-permalink.php">Enable now &raquo;</a>', 'dp-lang' ) . '</p></div>';
      	}

        /**
         * Handle the Edit Screens
         */
        function handle_edit_screen_filter($request) {
            if (is_admin()) {
                global $current_screen;

                if ($current_screen->id == 'edit-duka') {

                    //Switches the product_category ids to slugs as you can't query custom taxonomys with ids
                    if (!empty($request['duka_category'])) {
                        $cat = get_term_by('id', $request['duka_category'], 'duka_category');
                        $request['duka_category'] = $cat->slug;
                    }
                }
                else if ($current_screen->id == 'duka_page_dukapress-orders' && !isset($_GET['post_status'])) {

                    //set the post status when on "All" to everything but closed
                    $request['post_status'] = 'order_received,order_paid,order_shipped';
                }
            }

            return $request;
        }

        /**
         * Hanlde the Post updated messages
         *
         */
        function post_updated_messages($messages) {
            global $post, $post_ID;

            $post_type = get_post_type($post_ID);

            if ($post_type != 'duka_order' && $post_type != 'duka') {
                return $messages;
            }
            $obj = get_post_type_object($post_type);
            $singular = $obj->labels->singular_name;

            $messages[$post_type] = array(0 => '',
             // Unused. Messages start at index 1.
            1 => sprintf(__($singular . ' updated. <a href="%s">View ' . strtolower($singular) . '</a>'), esc_url(get_permalink($post_ID))), 
			2 => __('Custom field updated.'), 
			3 => __('Custom field deleted.'), 
			4 => __($singular . ' updated.'), 
			5 => isset($_GET['revision']) ? sprintf(__($singular . ' restored to revision from %s'), wp_post_revision_title((int)$_GET['revision'], false)) : false, 
			6 => sprintf(__($singular . ' published. <a href="%s">View ' . strtolower($singular) . '</a>'), esc_url(get_permalink($post_ID))), 
			7 => __('Page saved.'), 
			8 => sprintf(__($singular . ' submitted. <a target="_blank" href="%s">Preview ' . strtolower($singular) . '</a>'), esc_url(add_query_arg('preview', 'true', get_permalink($post_ID)))), 
			9 => sprintf(__($singular . ' scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview ' . strtolower($singular) . '</a>'), date_i18n(__('M j, Y @ G:i'), strtotime($post->post_date)), esc_url(get_permalink($post_ID))), 10 => sprintf(__($singular . ' draft updated. <a target="_blank" href="%s">Preview ' . strtolower($singular) . '</a>'), esc_url(add_query_arg('preview', 'true', get_permalink($post_ID)))),);

            return $messages;
        }



        /**
		* Create the Admin Menu
		*
		*
		*/
		function admin_menu() {
			$order_cap = apply_filters('duka_orders_cap', 'edit_others_posts');
			if (current_user_can($order_cap) && !$this->get_setting('disable_cart')) {
				$num_posts = wp_count_posts('duka_order');
				 //get pending order count
				$count = $num_posts->order_received + $num_posts->order_paid;
				if ($count > 0)
					$count_output = '&nbsp;<span class="update-plugins"><span class="updates-count count-' . $count . '">' . $count . '</span></span>';
				else
					$count_output = '';
			}
			$page = add_submenu_page('edit.php?post_type=duka', __('Store Settings', 'dp-lang'), __('Store Settings', 'dp-lang'), 'manage_options', 'dukapress', array(&$this, 'admin_page'));
			add_action('admin_print_scripts-' . $page, array(&$this, 'admin_script_settings'));
			add_action('admin_print_styles-' . $page, array(&$this, 'admin_css_settings'));
            add_submenu_page('edit.php?post_type=duka', __('Documentation', 'dp-lang'), __('Documentation', 'dp-lang'), 'manage_options', 'documentation', array(&$this, 'documentation'));
		}

		/**
		* Javascript for the screens
		*/
		function admin_script_post() {
		  global $current_screen;
		  if ($current_screen->id == 'duka'){
				wp_enqueue_script('duka-post', DPSC_DUKAPRESS_RESOURCEURL . '/js/post-screen.js', array('jquery'), $this->version);
				
				//For the variations
				wp_enqueue_script('duka-variation-tag', DPSC_DUKAPRESS_RESOURCEURL . '/tags/jquery.tagsinput.js', array('jquery'), $this->version);
				wp_register_style('duka_jquery_tags_input', DPSC_DUKAPRESS_RESOURCEURL . '/tags/jquery.tagsinput.min.css');
				wp_enqueue_style('duka_jquery_tags_input');
              
                wp_enqueue_script('duka-variation-chosen', DPSC_DUKAPRESS_RESOURCEURL . '/chosen/chosen.jquery.min.js', array('jquery'), $this->version);
				wp_register_style('duka_jquery_chosen_css', DPSC_DUKAPRESS_RESOURCEURL . '/chosen/chosen.min.css');
				wp_enqueue_style('duka_jquery_chosen_css');
          }
          if ($current_screen->id == 'duka_order'){
              wp_enqueue_script('duka-order', DPSC_DUKAPRESS_RESOURCEURL . '/js/order-screen.js', array('jquery'), $this->version);
          }
          if($current_screen->id == 'edit-duka_variation'){
              wp_enqueue_script('duka-variation-screen', DPSC_DUKAPRESS_RESOURCEURL . '/js/variation-screen.js', array('jquery'), $this->version);
          }
		}

		/**
    	* Admin Page
        */
        function admin_page() {
			global $wpdb;
			if (!current_user_can('manage_options')) {
				echo "<p>" . __('Invalid Access', 'dp-lang') . "</p>";
				return;
			}
			?>
			<div class="wrap">
                <h2><?php _e("Settings","dp-lang"); ?></h2>
				<h3 class="nav-tab-wrapper">
				<?php
				$tab = (!empty($_GET['tab'])) ? $_GET['tab'] : 'main';
				if (!$this->get_setting('disable_cart')) {
					$tabs = array('coupons' => __('Discount Codes', 'dp-lang'), 'email' => __('Email', 'dp-lang'), 'shipping' => __('Shipping', 'dp-lang'), 'gateways' => __('Payments', 'dp-lang'), 'checkout' => __('Checkout Page', 'dp-lang'), 'tools' => __('Tools', 'dp-lang'));
				}
				else {
					$tabs = array( 'tools' => __('Tools', 'dp-lang'));
				}
				$tabhtml = array();
				$class = ('main' == $tab) ? ' nav-tab-active' : '';
				$tabhtml[] = '<a href="' . admin_url('edit.php?post_type=duka&amp;page=dukapress') . '" class="nav-tab' . $class . '">' . __('General', 'dp-lang') . '</a>';

				foreach ($tabs as $stub => $title) {
					$class = ($stub == $tab) ? ' nav-tab-active' : '';
					$tabhtml[] = ' <a href="' . admin_url('edit.php?post_type=duka&amp;page=dukapress&amp;tab=' . $stub) . '" class="nav-tab' . $class . '">' . $title . '</a>';
				}
				echo implode("\n", $tabhtml);
					  ?>
				  </h3>
				  <div class="clear"></div>
				  <?php
    			  $settings = get_option('dukapress_settings');

    			  //Save settings. General save for all settings
    			  if (isset($_POST['dukapress_settings']) && check_admin_referer('dukapress_settings', 'dukapress_settings_noncename')) {
    				  $settings = array_merge($settings, apply_filters('dukapress_main_settings_filter', $_POST['dpsc']));
    				  update_option('dukapress_settings', $settings);
					  $settings = get_option('dukapress_settings');

    			  }
    			  switch ($tab) {
    				  case "main":
    					  DukaPress_Admin_Pages::main($settings);
    					  break;

    				  case "coupons":
    					  DukaPress_Admin_Pages::coupons($settings);
    					  break;

    				  case "email":
    					  DukaPress_Admin_Pages::email($settings);
    					  break;

    				  case "shipping":
    					  DukaPress_Admin_Pages::shipping($settings);
    					  break;

    				  case "gateways":
    					  DukaPress_Admin_Pages::payment($settings);
    					  break;

    				  case "checkout":
    					  DukaPress_Admin_Pages::checkout();
    					  break;

    				  case "tools":
                          DukaPress_Admin_Pages::tools();
    					  break;
    			  }
    			?>
    		</div>
    		<?php
    	}
        
        /**
         * Documentation Page
         *
         */
        function documentation(){
            ?>
            <div class="wrap">
                <h2><?php _e("Documentation","dp-lang"); ?></h2>
				<p><?php echo sprintf( __("Please visit %shere%s for documentation","dp-lang"), '<a href="http://dukapress.org/docs" target="_blank">', '</a>'); ?></p>
            </div>
            <?php
        }

		/**
		 * Create Google Analytics Commerce
		 * Called after a form is submitted
		 * 
         */
		function ga_ecommerce( $order ) {
			if ( !is_object( $order ) )
				 return false;
            
            $meta = get_post_custom($order->ID);
            foreach ($meta as $key => $val)
                $meta[$key] = array_map('maybe_unserialize', $val);
            
            $total_order = $meta["duka_order_total"][0];
            $total_tax = $meta["duka_tax_total"][0];
            $total_shipping = $meta["duka_shipping_total"][0];
            
            $country = "";
            $state = "";
            $item_index =  array_search('dpsc_country', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $country = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            $item_index =  array_search('dpsc_state', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $state  = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            
            $cart = $meta["dpsc_cart_info"][0];

			if ( $this->get_setting( 'ga_ecommerce' ) == 'old' ) {
				$js = '<script type="text/javascript">
						try{
						pageTracker._addTrans(
							"' . esc_js( $order->post_title ) . '",							 // order ID - required
							"' . esc_js( $this->get_setting( 'shop_name' ) ) . '",			 // affiliation or store name
							"' . $total_order . '",								 // total - required
							"' . $total_tax . '",									 // tax
							"' . $total_shipping . '",							 // shipping
							"' . esc_js( $state ) . '",		// city
							"' . esc_js( $state ) . '",		 // state or province
							"' . esc_js( $country ) . '"	 // country
						);';
				if ( is_array( $cart ) && count( $cart ) ) {
                    foreach ($cart as $key => $dpsc_product) {
                        $product = get_post($dpsc_product['item_number']);
                        $js .= 'pageTracker._addItem(
                            "' . esc_js( $order->post_title ) . '", // order ID - necessary to associate item with transaction
                            "' . $product->ID . '",									 // SKU/code - required
                            "' . esc_js( $product->post_title ) . '",		// product name
                            "' . $product[ 'price' ] . '",						// unit price - required
                            "' . $product[ 'quantity' ] . '"					 // quantity - required
                        );';
                    }
				}
				$js .= 'pageTracker._trackTrans(); //submits transaction to the Analytics servers
						} catch(err) {}
						</script>';

			}else if ( $this->get_setting( 'ga_ecommerce' ) == 'new' ) {
				$js = '<script type="text/javascript">
						_gaq.push(["_addTrans",
							"' . esc_js( $order->post_title ) . '",							 // order ID - required
							"' . esc_js( $this->get_setting( 'shop_name' ) ) . '",			 // affiliation or store name
							"' . $total_order . '",								 // total - required
							"' . $total_tax . '",									 // tax
							"' . $total_shipping . '",							 // shipping
							"' . esc_js( $state ) . '",		// city
							"' . esc_js( $state ) . '",		 // state or province
							"' . esc_js( $country ) . '"	 // country
						]);';
				if ( is_array( $cart ) && count( $cart ) ) {
                    
                    foreach ($cart as $key => $dpsc_product) {
                        $product = get_post($dpsc_product['item_number']);
                        $js .= '_gaq.push(["_addItem",
								"' . esc_attr( $order->post_title ) . '", // order ID - necessary to associate item with transaction
								"' . $product->ID . '",									 // SKU/code - required
								"' . esc_attr( $product->post_title ) . '",			// product name
								"",												// category
								"' . $data[ 'price' ] . '",						// unit price - required
								"' . $data[ 'quantity' ] . '"					 // quantity - required
							]);';
                    }
				}
				$js .= '_gaq.push(["_trackTrans"]);
						</script>';

			}else if ( $this->get_setting( 'ga_ecommerce' ) == 'universal' ) {
				$js = '<script type="text/javascript">
						ga("require", "ecommerce", "ecommerce.js");
						ga("ecommerce:addTransaction", {
								"id": "' . esc_attr( $order->post_title ) . '",						// Transaction ID. Required.
								"affiliation": "' . esc_attr( $this->get_setting( 'shop_name' )) . '",	// Affiliation or store name.
								"revenue": "' . $total_order . '",						// Grand Total.
								"shipping": "' . $total_shipping . '",					// Shipping.
								"tax": "' . $total_tax . '"							 		// Tax.
						});';
				if ( is_array( $cart ) && count( $cart ) ) {
					 foreach ($cart as $key => $dpsc_product) {
                        $product = get_post($dpsc_product['item_number']);
                        $js .= 'ga("ecommerce:addItem", {
                             "id": "' . esc_attr( $order->post_title ) . '", // Transaction ID. Required.
                             "name": "' . esc_attr( $product->post_title ) . '",	 // Product name. Required.
                             "sku": "' . $product->ID . '",								// SKU/code.
                             "category": "",			 					// Category or variation.
                             "price": "' . $data[ 'price' ] . '",				 // Unit price.
                             "quantity": "' . $data[ 'quantity' ] . '"		 // Quantity.
                        });';
					}
				}

				$js .='ga("ecommerce:send");</script>';
			}
			if ( !empty( $js ) ) {
				$function = "echo '$js';";
				add_action( 'wp_footer', create_function( '', $function ), 99999 );
			}

		}

		/**
		* Save Discount Code
		*/
		function save_discount_code() {
			$discount_code = $_POST['dpsc_discount_code'];
			$discount_amount = $_POST['dpsc_discount_amount'];
			$discount_one_time = $_POST['dpsc_discount_one_time'];
			$output = '';
			$unique_discount = TRUE;
			$discount = get_option('dpsc_discount_codes') ? get_option('dpsc_discount_codes') : array();
			foreach ($discount as $check_code) {
				if ($check_code['code'] === $discount_code) {
				  $unique_discount = FALSE;
				}
			}
			if ($unique_discount) {
				if (!empty($discount_code) && !empty($discount_amount)) {
					$dpsc_discount['code'] = $discount_code;
					$dpsc_discount['amount'] = $discount_amount;
					$dpsc_discount['count'] = 0;
					$dpsc_discount['one_time'] = $discount_one_time;
					$dpsc_discount['id'] = time();
					$discount[] = $dpsc_discount;
					update_option('dpsc_discount_codes', $discount);
				}
			}
			else {
				$output = '<span id="dpsc-same-discount-code-present">Please add another discount code as same discount code already exists.</span>';
			}
			if ($_REQUEST['ajax'] == 'true') {
				ob_start();
				_e(DukaPress_Admin_Pages::discount_code_table(), "dp-lang");
				$output.= ob_get_contents();
				ob_end_clean();
				die($output);
			}
		}

        /**
        * This function deletes the Discount code
        *
        */
        function delete_discount_code() {
			$dpsc_discount_code_id = intval($_POST['id']);
			$dpsc_discount_codes = get_option('dpsc_discount_codes');
			$dpsc_discount_codes_new = array();
			if (is_array($dpsc_discount_codes)) {
			  foreach ($dpsc_discount_codes as $check_code) {
				  if ($check_code['id'] === $dpsc_discount_code_id) {
					  unset($check_code);
				  }
				  else {
					  $dpsc_discount_codes_new[] = $check_code;
				  }
			  }
			}
			update_option('dpsc_discount_codes', $dpsc_discount_codes_new);
			if ($_REQUEST['ajax'] == 'true') {
			  ob_start();
			  _e(DukaPress_Admin_Pages::discount_code_table(), "dp-lang");
			  $output.= ob_get_contents();
			  ob_end_clean();
			  die($output);
			}
        }



		/**
		* CSS used on theme
		*
		*/
		function set_up_styles() {
			wp_register_style('dpsc_basic_css', DPSC_DUKAPRESS_RESOURCEURL . '/css/dpsc-basic.css');
			wp_register_style('jquery.fancybox', DPSC_DUKAPRESS_RESOURCEURL . '/js/jquery.fancybox/jquery.fancybox.css', false, $this->version, 'screen');
			wp_register_style('dpsc_jqzoom', DPSC_DUKAPRESS_RESOURCEURL . '/css/jqzoom.css', false, $this->version, 'screen');
			wp_enqueue_style('dp_acc_style');
			wp_enqueue_style('dpsc_basic_css');
		}

		/**
		* Javascript used on Theme
		*
		*/
		function set_up_js() {
			add_theme_support('html5');
            wp_enqueue_script('jquery-form');
            wp_register_script('jquery-validate', DPSC_DUKAPRESS_RESOURCEURL . '/js/jquery.validate.min.js', array('jquery'), $this->version);
            wp_enqueue_script('jquery-validate');
			wp_register_script('dpsc_magiczoom', DPSC_DUKAPRESS_RESOURCEURL . '/js/magiczoom.js', array('jquery'), $this->version);
			wp_register_script('dpsc_magiczoomplus', DPSC_DUKAPRESS_RESOURCEURL . '/js/magiczoomplus.js', array('jquery'), $this->version);
			wp_register_script('dpsc_lightbox', DPSC_DUKAPRESS_RESOURCEURL . '/js/jquery.fancybox/jquery.fancybox-1.2.1.pack.js', array('jquery'), $this->version);
			wp_register_script('dpsc_lightbox_call', DPSC_DUKAPRESS_RESOURCEURL . '/js/lightbox.js', array('jquery', 'dpsc_lightbox'), $this->version);
			wp_register_script('dpsc_jqzoom', DPSC_DUKAPRESS_RESOURCEURL . '/js/jqzoom.pack.1.0.1.js', array('jquery'), $this->version);
			

			$image_effect = $this->get_setting('image_effect');
			switch ($image_effect) {
				case 'mz_effect':
				  wp_enqueue_script('dpsc_magiczoom');
				  break;

				case 'mzp_effect':
				  wp_enqueue_script('dpsc_magiczoomplus');
				  break;

				case 'lightbox':
				  wp_enqueue_style('jquery.fancybox');
				  wp_enqueue_script('dpsc_lightbox');
				  wp_enqueue_script('dpsc_lightbox_call');
				  break;

				case 'no_effect':
				  break;

				case 'jqzoom_effect':
				  wp_enqueue_style('dpsc_jqzoom');
				  wp_enqueue_script('dpsc_jqzoom');
				  break;

				default:
				  break;
			}
			$dpsc_site_url = get_bloginfo('url');
            wp_register_script('dpsc_js_file', DPSC_DUKAPRESS_RESOURCEURL . '/js/dukapress.js', array('jquery'), $this->version);
			wp_enqueue_script('dpsc_js_file');
			wp_localize_script('dpsc_js_file', 'dpsc_js', array('dpsc_url' => $dpsc_site_url, 'ajaxurl' => admin_url('admin-ajax.php'), 'resourcesurl' => DPSC_DUKAPRESS_RESOURCEURL, 'text_error' => __("Please write only text here", "dp-lang"), 'numbers_error' => __("Please write only numbers here", "dp-lang"), 'email_error' => __("Please put the right email id", "dp-lang"), 'processing' => __("Processing, please wait", "dp-lang"), 'error' => __("An error occured. Please try again", "dp-lang"), 'emptycart' => __("Are you sure you want to empty the cart?", "dp-lang")));
			wp_enqueue_script('dpsc_livequery');
		}

		/**
		* Enqeue js on product settings screen
		*/
		function admin_script_settings() {
			wp_enqueue_script('jquery-ui-sortable');
			wp_enqueue_script('jquery-ui-accordion');
			wp_enqueue_script('dukapress-admin', DPSC_DUKAPRESS_RESOURCEURL . '/js/dukapress-admin.js', array('jquery'), $this->version);
		}

		/**
		* Enqeue css on product settings screen
		*/
		function admin_css_settings() {
			wp_enqueue_style('dp_jquery_ui', DPSC_DUKAPRESS_RESOURCEURL . '/css/jquery-ui.min.css', false, $this->version);
			wp_enqueue_style('dp_jquery_ui_structure', DPSC_DUKAPRESS_RESOURCEURL . '/css/jquery-ui.structure.min.css', false, $this->version);
			wp_enqueue_style('dp_jquery_ui_theme', DPSC_DUKAPRESS_RESOURCEURL . '/css/jquery-ui.theme.min.css', false, $this->version);
			wp_enqueue_style('dp_admin_css', DPSC_DUKAPRESS_RESOURCEURL . '/css/dp-admin.css', false, $this->version);
		}


		/**
		* Add Settings option on the plugin list
		*/
		function plugin_action_link($links, $file) {

			// the anchor tag and href to the URL we want. For a "Settings" link, this needs to be the url of your settings page
			$settings_link = '<a href="' . admin_url('edit.php?post_type=duka&page=dukapress') . '">' . __('Settings', 'dp-lang') . '</a>';
            $documentation_link = '<a href="http://dukapress.org/docs/" target="_blank">' . __('Documentation', 'dp-lang') . '</a>';
            $support_link = '<a href="http://dukapress.org/support/" target="_blank">' . __('Support', 'dp-lang') . '</a>';
			// add the link to the list
			array_unshift($links, $settings_link);
            array_unshift($links, $documentation_link);
            array_unshift($links, $support_link);
			return $links;
		}
		
		/**
		 * Admin Bar
		 *
		 */
		function admin_bar_menu($wp_admin_bar){
			$args = array(
				'id' => 'dukapress',
				'title' => 'DukaPress', 
				'href' => admin_url('edit.php?post_type=duka&page=dukapress'), 
				'meta' => array(
					'class' => 'dukapress', 
					'title' => 'DukaPress'.__(' Settings', 'dp-lang')
					)
				);
			$wp_admin_bar->add_node($args);
		}


        /**
         * Add Shortcode to all porducts
         */
        function content_filter($content){
      		$post_id = $GLOBALS['post']->ID;
			if($this->get_setting('product_shortcode')){
				$post_type = get_post_type( $post_id );
				$search_query = get_query_var( 's');
				if($post_type == 'duka')
					if(empty($search_query))
						$content .= '<br/>'. dukapress_single_product();
			}
      		return $content;
      	}

		/**
		* Generate the excerpt for the product
		*
		*
		*/
		function product_excerpt($excerpt, $content, $product_id, $excerpt_more = null) {
			if (is_null($excerpt_more)) $excerpt_more = ' <a class="dpsc_product_more_link" href="' . get_permalink($product_id) . '">' . __('More Info &raquo;', 'dp-lang') . '</a>';
			if ($excerpt) {
				return apply_filters('get_the_excerpt', $excerpt) . $excerpt_more;
			}
			else {
				$text = strip_shortcodes($content);

				//$text = apply_filters('the_content', $text);
				$text = str_replace(']]>', ']]&gt;', $text);
				$text = strip_tags($text);
				$excerpt_length = apply_filters('excerpt_length', 55);
				$words = preg_split("/[\n\r\t ]+/", $text, $excerpt_length + 1, PREG_SPLIT_NO_EMPTY);
				if (count($words) > $excerpt_length) {
					array_pop($words);
					$text = implode(' ', $words);
					$text = $text . $excerpt_more;
				}
				else {
					$text = implode(' ', $words);
				}
			}
			return $text;
		}

        /**
         * Check the discount code
         */
        function check_discount($code){
            $check =  array('valid' => false, 'amount' => 0.00);
            if(!isset($_SESSION['dpsc_discount']) && empty($_SESSION['dpsc_discount'])){
                $dpsc_discount_codes = get_option('dpsc_discount_codes');
                if (is_array($dpsc_discount_codes)) {
                    foreach ($dpsc_discount_codes as $check_code) {
                        if ($check_code['code'] === $code) {
                            $one_time = FALSE;
                            if ($check_code['one_time'] === 'true') {
                                if ($check_code['count'] != 0) {
                                    $one_time = TRUE;
                                }
                            }
                            if (!$one_time) {
                                $check['valid'] = true;
                                $check['amount'] = floatval($check_code['amount']);
                                break;
                            }
                        }
                    }
                }
            }
            //Validate Dukapress discount plugin code
        	global $dp_desc;
        	if(isset($dp_desc)){
        		$dp_discount_percentage = dp_disc_validate_discounts($discount_code);
        		if($dp_discount_percentage['exists'] == 'true'){
              $check['amount'] = $check['amount'] + $dp_discount_percentage['value'];
        		}
        	}
            return $check;
        }
        
        
        function update_discount_usage($code){
            $dpsc_discount_codes = get_option('dpsc_discount_codes');
            if (is_array($dpsc_discount_codes)) {
                $updated_discount_codes = array();
                foreach ($dpsc_discount_codes as $check_code) {
                    if ($check_code['code'] === $code) {
                        $check_code['count']++;
                    }
                    $updated_discount_codes[] = $check_code;
                }
                update_option('dpsc_discount_codes', $updated_discount_codes);
            }
        }

    	//returns a new unique order id.
		function generate_order_id() {
			global $wpdb;

			$count = true;
			while ($count) {
			   //make sure it's unique
			  $order_id = substr(sha1(uniqid('')), rand(1, 24), 12);
			  $count = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM " . $wpdb->posts . " WHERE post_title = %s AND post_type = 'duka_order'", $order_id));
			}

			$order_id = apply_filters('duka_order_id', $order_id);
			//Very important to make sure order numbers are unique and not sequential if filtering
			//save it to session
			$_SESSION['duka_order'] = $order_id;

			return $order_id;
		}

    	//called on checkout to create a new order
    	function create_order($order_id, $cart, $user_info, $shipping_info, $payment_info, $paid, $order_total, $user_id = false,  $shipping_total = false, $tax_total = false, $total_discount = false, $coupon_code = false) {

    		if (empty($order_id))
				$order_id = $this->generate_order_id();
    		else if ($this->get_order($order_id))
    		   //don't continue if the order exists
				return false;

			$order = array();
            $items = array();
			$order['post_title'] = $order_id;
			$order['post_name'] = $order_id;
			$order['post_content'] = serialize($cart) . serialize($shipping_info). serialize($user_info);
			//this is purely so you can search by cart contents
			$order['post_status'] = ($paid) ? 'order_paid' : 'order_received';
			$order['post_type'] = 'duka_order';
			$post_id = wp_insert_post($order);

			//cart info
			add_post_meta($post_id, 'dpsc_cart_info', $cart, true);
            
            //user info
			add_post_meta($post_id, 'dpsc_user_info', $user_info, true);
            
            //payment info
			add_post_meta($post_id, 'dpsc_payment_info', $payment_info, true);

			//shipping info
			add_post_meta($post_id, 'dpsc_shipping_info', $shipping_info, true);

			foreach ($cart as $key => $product) {
				$product_id = $product['item_number'];
				$items[] = $product['quantity'];
				$stock = maybe_unserialize(get_post_meta($product_id, 'currently_in_stock', true));
				$stock = $stock - $product['quantity'];
                if($stock < 0)
                    $stock = 0;
                if ($this->get_setting('inventory_active'))
				    update_post_meta($product_id, 'currently_in_stock', $stock);
				if ($stock <= $this->get_setting('inventory_threshhold') && $this->get_setting('inventory_active')) {
				  DukaPress_Mail::low_stock_notification($product_id, $stock);
				}
				if ($this->get_setting('inventory_active') && $this->get_setting('inventory_remove') && $stock <= 0) {
				  wp_update_post(array('ID' => $product_id, 'post_status' => 'out_of_stock'));
				}

				$count = get_post_meta($product_id, 'duka_sales_count', true);
				$count+= $product['quantity'];
				update_post_meta($product_id, 'duka_sales_count', $count);
			}
			$item_count = array_sum($items);
            
            $discount = array('discount' => $total_discount, 'code' => $coupon_code);
			add_post_meta($post_id, 'duka_order_total', $order_total, true);
			add_post_meta($post_id, 'duka_shipping_total', $shipping_total, true);
			add_post_meta($post_id, 'duka_tax_total', $tax_total, true);
			add_post_meta($post_id, 'duka_order_items', $item_count, true);
            add_post_meta($post_id, 'duka_discount_info', $discount, true);

			$timestamp = time();
			add_post_meta($post_id, 'duka_received_time', $timestamp, true);

			if ($paid) {
			  add_post_meta($post_id, 'duka_paid_time', $timestamp, true);
			  do_action('duka_order_paid', $this->get_order($order_id));
			}

			if ($this->get_setting('user_registration')) {
			  if (!$user_id) $user_id = get_current_user_id();

			  if ($user_id) {
				  $orders = get_user_meta($user_id, 'duka_order_history', true);
				  $timestamp = time();
				  $orders[$timestamp] = array('id' => $order_id, 'total' => $order_total);
				  update_user_meta($user_id, 'duka_order_history', $orders);
			  }else{
                  //add new user
                  $user_pass = wp_generate_password();
                  $user_id = wp_create_user($user_info['dpsc_email'], $user_pass, $user_info['dpsc_email']);
                  update_user_option($user_id, 'default_password_nag', true, true);
                  $timestamp = time();
				  $orders[$timestamp] = array('id' => $order_id, 'total' => $order_total);
				  update_user_meta($user_id, 'duka_order_history', $orders);
                  
                  DukaPress_Mail::new_user_registration($user_info['dpsc_email'],$user_pass,$user_info['dpsc_email']);
              }
			}
			return $order_id;
    	}

		/**
		* Convert $user_info to a string value containing the name and value
		* Normally in this format :
		* <code>
		* $userinfo = array();
		* $userinfo[] = array('First Name' => 'First');
		* $userinfo[] = array('Last Name' => 'Last');
		* $userinfo[] = array('Email' => 'name@domain.com');
		* </code>
		* @param Array $userinfo
        * @param Array $shippinginfo
		*/
		function user_info_to_string($userinfo = array(), $shippinginfo = array()) {
            $content = '';
            $content .= '<table>';
            $content .= '<tr>';
            $content .= '<td width="50%" style="border-right:1px solid #cccccc">';
            if(is_array($userinfo) && count($userinfo) > 0){
                $content .= '<h2 class="title"><strong>'.__("Customer Information","dp-lang").'</strong></h2>';
                $content .= '<table width="100%" border="0" class="form-table">';
                foreach($userinfo as $key => $value){
                    $content .= '<tr>';
                    $content .= '<th align="left" scope="row">'.$value['name'].'</th><td>'.$value['value'].'</td>';
                    $content .= '</tr>';
                }
                $content .= '</table>';
            }
            $content .= '</td>';
            $content .= '<td width="48%" style="padding-left:1%">';
            if(is_array($shippinginfo) && count($shippinginfo) > 0){
                $content .= '<h2 class="title"><strong>'.__("Shipping Information","dp-lang").'</strong></h2>';
                $content .= '<table width="100%" border="0" class="form-table">';
                foreach($shippinginfo as $key => $value){
                    $content .= '<tr>';
                    $content .= '<th align="left" scope="row">'.$value['name'].'</th><td>'.$value['value'].'</td>';
                    $content .= '</tr>';
                }
                $content .= '</table>';

            }
            $content .= '</td>';
            $content .= '</tr>';
            $content .= '</table>';
            return $content;
		}
        
        /**
         * Order Info To String
         *
         */
        function order_info_to_string($order){
            $content = '';
                        
            $meta = get_post_custom($order->ID);
            //unserialize
            foreach ($meta as $key => $val)
                $meta[$key] = array_map('maybe_unserialize', $val);

            $order_status = __('Received', 'dp-lang');
            if ($order->post_status == 'order_received')
                $order_status = __('Received', 'dp-lang');
            else if ($order->post_status == 'order_paid')
                $order_status = __('Paid', 'dp-lang');
            else if ($order->post_status == 'order_shipped')
                $order_status = __('Shipped', 'dp-lang');
            else if ($order->post_status == 'order_closed')
                $order_status = __('Closed', 'dp-lang');
            else if ($order->post_status == 'trash')
                $order_status = __('Trashed', 'dp-lang');

            $title = get_the_title( $order );

            $t_time = get_the_time(__('Y/m/d g:i:s A'));
            $m_time = $order->post_date;
            $time = get_post_time('G', true, $order);

            $time_diff = time() - $time;

            if ($time_diff > 0 && $time_diff < 24 * 60 * 60) $h_time = sprintf(__('%s ago'), human_time_diff($time));
            else $h_time = mysql2date(__('Y/m/d'), $m_time);

            $total_items = number_format_i18n($meta["duka_order_items"][0]);

            $total_order = $meta["duka_order_total"][0];

            $payment_method = $meta["dpsc_payment_info"][0]['name'];
            
            $content .= '<table width="100%" border="0" class="form-table">';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Invoice","dp-lang").'</th><td>'.$title.'</td>';
            $content .= '</tr>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Date Received","dp-lang").'</th><td>'.$h_time.'</td>';
            $content .= '</tr>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Total Items","dp-lang").'</th><td>'.$total_items.'</td>';
            $content .= '</tr>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Total Tax","dp-lang").'</th><td>'.$this->format_currency('', $meta["duka_tax_total"][0]).'</td>';
            $content .= '</tr>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Total Discount","dp-lang").'</th>';
            $content .= '<td>';
            if (isset($meta["duka_discount_info"][0]) && $meta["duka_discount_info"][0]) {
                $content .= $meta["duka_discount_info"][0]['discount'] . ' (' . strtoupper($meta["duka_discount_info"][0]['code']) . ')';
            }
            else {
               $content .= __('N/A', 'dp-lang');
            }
            $content .= '</td>';
            $content .= '</tr>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Total Shipping","dp-lang").'</th>';
            $content .= '<td>';
            if(isset($meta["duka_shipping_total"]))
                $content .= $this->format_currency('', $meta["duka_shipping_total"][0]);
            else
                $content .= __('N/A', 'dp-lang');
            $content .= '</td>';
            $content .= '</tr>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Total Amount","dp-lang").'</th><td>'.$this->format_currency( '',$total_order).'</td>';
            $content .= '</tr>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Payment Method","dp-lang").'</th><td>'.$payment_method.'</td>';
            $content .= '</tr>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="row">'.__("Order Status","dp-lang").'</th><td class="dpsc_order_status">'.$order_status.'</td>';
            $content .= '</tr>';
            $content .= '</table>';
            $content .= '<hr/>';
            $cart = $meta["dpsc_cart_info"][0];
            $content .= '<h2 class="title"><strong>'.__("Product Information","dp-lang").'</strong></h2>';
            $content .= '<table width="100%" border="0" class="widefat">';
            $content .= '<thead>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="col">'.__("Name","dp-lang").'</th>';
            $content .= '<th align="left" scope="col">'.__("Quantity","dp-lang").'</th>';
            $content .= '<th align="left" scope="col">'.__("Unit Price","dp-lang").'</th>';
            $content .= '<th align="left" scope="col">'.__("Total Price","dp-lang").'</th>';
            $content .= '</tr>';
            $content .= '</thead>';
            $content .= '<tbody>';
            foreach ($cart as $key => $dpsc_product) {
                $dpsc_var = '';
                if (!empty($dpsc_product['var'])) {
                    $dpsc_var = ' (' . $dpsc_product['var'] . ')';
                }
                $product = get_post($dpsc_product['item_number']);
                $view_link = get_permalink($dpsc_product['item_number']);
                $prod_price = $dpsc_product['price'] * $dpsc_product['quantity'];
                $content .= '<tr>';
                $content .= '<td>';
                $content .= '<a href="'.$view_link.'" target="_blank" title="'.__('View','dp-lang').' '.$product->post_title.'">'.$product->post_title.$dpsc_var.'</a>';
                $content .= '</td>';
                $content .= '<td>'.$dpsc_product['quantity'].'</td>';
                $content .= '<td>'.$this->format_currency( '',$dpsc_product['price']).'</td>';
                $content .= '<td>'.$this->format_currency( '', $prod_price ).'</td>';
                $content .= '</tr>';
            }
            $content .= '</tbody>';
            $content .= '</table>';
            return $content;
        }


		/**
		* Get Order by id
		*
		*/
		function order_to_post_id($order_id) {
		  $order = get_page_by_title($order_id, OBJECT, 'duka_order');
		  return $order->ID;
		}

        
        /**
         * Upate Orer Status
         *
         */
		function update_order_status($order_id, $new_status) {
            $status = "order_received";
            switch($new_status){
                case 'paid':
                    $status = "order_paid";
                    break;
                case 'shipped':
                    $status = "order_shipped";
                    break;
                case 'closed':
                    $status = "order_closed";
                    break;
                case 'received':
                    $status = "order_received";
                    break;
                case 'cancelled':
                    $status = "order_cancelled";
                    break;
            }
            $this->change_order_status($order_id, $status);
            
		}
        
        /**
         * change the order status
         */
        function change_order_status($order_id, $status){
            wp_update_post( array( 'ID' => $order_id, 'post_status' => $status ) );
        }

		//returns the full order details as an object
		function get_order($order_id) {
            $id = (is_int($order_id)) ? $order_id : $this->order_to_post_id($order_id);

            if (empty($id)) return false;

            $order = get_post($id);
            if (!$order) return false;

            $meta = get_post_custom($id);

            //unserialize a and add to object
            foreach ($meta as $key => $val) $order->$key = maybe_unserialize($meta[$key][0]);

            return $order;
		}
        
        /**
         * This function will convert old style arguments (broken out into variables) and convert into an array
         * @param mixed $args
         * @param array $defaults
         * @return array
         */
        function parse_args( $args, $defaults ) {
            if ( !isset( $args[ 0 ] ) )
                return $defaults;

            if ( (isset( $args[ 0 ] ) && is_array( $args[ 0 ] )) || (isset( $args[ 0 ] ) && !is_numeric( $args[ 0 ] ) && !is_bool( $args[ 0 ] )) )
                return wp_parse_args( $args[ 0 ], $defaults );

            $tmp_args = array();

            foreach ( $defaults as $key => $value ) {
                $val			 = array_shift( $args );
                $tmp_args[ $key ]	 = !is_null( $val ) ? $val : $value;
            }

            return $tmp_args;
        }


	}
    $dukapress = DukaPress::instance();
}
?>
