<?php
class Dpsc_AuthorizeNet extends DukaPress_Gateway{
    
    var $currencies, $api, $transactionKey, $testRequest, $returnURL, $cancelURL, $postURL, $currencyCode;
    
    function on_create(){
		global $dukapress;
		$this->plugin_name = __('Authorize.net','dp-lang');
		$this->plugin_slug = 'authorizenet';
		$this->currencies = $dukapress->authorize_supported_currency;
        
        $this->plugin_public_name = $dukapress->get_setting('gateways->authorizenet->public');
        if(empty($this->plugin_public_name)){
            $this->plugin_public_name = $this->plugin_name;
        }
        
		$this->api = $dukapress->get_setting('gateways->authorizenet->api');
        $this->currencyCode = $dukapress->get_setting('gateways->authorizenet->currency');
        $this->transactionKey = $dukapress->get_setting('gateways->authorizenet->transaction_key');
        $this->testRequest = $dukapress->get_setting('gateways->authorizenet->test_request');

		//set api urls
        if ( $dukapress->get_setting('gateways->authorizenet->mode') == 'sandbox' )	{
            $this->postURL = "https://test.authorize.net/gateway/transact.dll";
        } else {
            $this->postURL = "https://secure.authorize.net/gateway/transact.dll";
        }
        $this->form_submit = true;
	}
    
    function set_up_options($settings){
		?>
		<h3 class='hndle'><span><?php _e('Authorize.net Settings','dp-lang'); ?></span></h3>
		<table class="form-table">
            <tr>
                <th scope="row"><?php _e('Public Name','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['authorizenet']['public']; ?>"  name="dpsc[gateways][authorizenet][public]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('Authorize.net Mode','dp-lang'); ?></th>
                <td>
                    <select name="dpsc[gateways][authorizenet][mode]">
                        <option value="sandbox" <?php selected($settings['gateways']['authorizenet']['mode'], 'sandbox'); ?>><?php _e('Sandbox','dp-lang'); ?></option>
                        <option value="live" <?php selected($settings['gateways']['authorizenet']['mode'], 'live'); ?>><?php _e('Live','dp-lang'); ?></option>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('Test-Request','dp-lang'); ?></th>
                <td>
                    <select name="dpsc[gateways][authorizenet][test_request]">
                        <option value="test" <?php selected($settings['gateways']['authorizenet']['test_request'], 'test'); ?>><?php _e('False','dp-lang'); ?></option>
                        <option value="live" <?php selected($settings['gateways']['authorizenet']['test_request'], 'live'); ?>><?php _e('True','dp-lang'); ?></option>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('Currency','dp-lang') ?></th>
                <td>
                    <select name="dpsc[gateways][authorizenet][currency]">
                        <?php
                        $sel_currency = $settings['gateways']['authorizenet']['currency'];
                        foreach ($this->currencies as $k => $v) {
                            echo '<option value="' . $k . '"' . ($k == $sel_currency ? ' selected' : '') . '>' . esc_html($v, true) . '</option>' . "\n";
                        }
                        ?>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('API Login','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['authorizenet']['api']; ?>"  name="dpsc[authorizenet][paypal][api]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('Transaction Key','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['authorizenet']['transaction_key']; ?>"  name="dpsc[authorizenet][paypal][transaction_key]" type="text" />
                </td>
            </tr>
		</table>
		
		<?php
	}
    
    
    function process_payment_form($cart, $user_info, $shipping, $order_id,$total_shipping, $total_discount, $total_tax,$dpsc_total, $return_path){
        global $dukapress;
        $conversion_rate = 1;
        if ($this->currencyCode != $dukapress->get_setting('shop_currency')) {
            $conversion_rate = dukapress_shop_currency_conversion_rate($this->currencyCode);
        }
        $total_amount = ($dpsc_total + $total_tax + $total_shipping - $total_discount) * $conversion_rate;
        $dpsc_total = number_format($total_amount, 2, '.', '');
        $sequence = rand(1, 1000);
        $timeStamp = time();
        if (phpversion() >= '5.1.2') {
            $fingerprint = hash_hmac("md5", $this->api . "^" . $sequence . "^" . $timeStamp . "^" . $dpsc_total . "^", $this->transactionKey);
        } else {
            $fingerprint = bin2hex(mhash(MHASH_MD5, $this->api . "^" . $sequence . "^" . $timeStamp . "^" . $dpsc_total . "^", $this->transactionKey));
        }
        $output .= '<form name="dpsc_authorize_form" id="dpsc_payment_form" action="' . $this->postURL . '" method="post">';
        $output .= '<input type="hidden" name="x_login" value="' . $this->api . '" />';
        $output .= '<input type="hidden" name="x_version" value="3.1" />';
        $output .= '<input type="hidden" name="x_method" value="CC" />';
        $output .= '<input type="hidden" name="x_type" value="AUTH_CAPTURE" />';
        $output .= '<input type="hidden" name="x_amount" value="' . $dpsc_total . '" />';
        $output .= '<input type="hidden" name="x_description" value="Your Order No.: ' . $order_id . '" />';
        $output .= '<input type="hidden" name="x_invoice_num" value="' . $order_id . '" />';
        $output .= '<input type="hidden" name="x_fp_sequence" value="' . $sequence . '" />';
        $output .= '<input type="hidden" name="x_fp_timestamp" value="' . $timeStamp . '" />';
        $output .= '<input type="hidden" name="x_fp_hash" value="' . $fingerprint . '" />';
        $output .= '<input type="hidden" name="x_test_request" value="' . $this->testRequest . '" />';
        $output .= '<input type="hidden" name="x_show_form" value="PAYMENT_FORM" />';
        $output .= '<input type="hidden" name="x_relay_response" value="TRUE" />';
        $output .= '<input type="hidden" name="x_relay_url" value="' . $this->ipn_url . '" />';
        $output .= '<input type="hidden" name="x_receipt_link_method" value="LINK" />';
        $output .= '<input type="hidden" name="x_receipt_link_text" value="Back to Shop" />';
        $output .= '<input type="hidden" name="x_receipt_link_URL" value="' . $return_path . '" />';
        $output .= '<input type="hidden" name="x_first_name" value="' . dukapress_checkout_setting_value($user_info, "dpsc_firstname") . '" />';
        $output .= '<input type="hidden" name="x_last_name" value="' . dukapress_checkout_setting_value($user_info, "dpsc_lastname") . '" />';
        $output .= '<input type="hidden" name="x_address" value="' . dukapress_checkout_setting_value($user_info, "dpsc_address") . '" />';
        $output .= '<input type="hidden" name="x_country" value="' . dukapress_checkout_setting_value($user_info, "dpsc_country") . '" />';
        $output .= '<input type="hidden" name="x_email" value="' . dukapress_checkout_setting_value($user_info, "dpsc_email") . '" />';
        $output .= '</form>';
        $this->send_gateway_output($output);
        
    }
    
    function update_payment($request){
        $payment_status = intval($_POST['x_response_code']);
        $invoice = $_POST['x_invoice_num'];
        $payer_email = $_POST['x_email'];
        switch ($payment_status) {
            case 1:
                $updated_status = 'paid';
                break;
            case 2:
                $updated_status = 'cancelled';
                break;
            case 3:
                $updated_status = 'cancelled';
                break;
            case 4:
                $updated_status = 'received';
                break;
            default:
                $updated_status = 'cancelled';
                break;
        }
        return $updated_status;
    }
    
    function process_ipn_return(){
        global $dukapress;
        $payment_status = intval($_POST['x_response_code']);
        $invoice = $_POST['x_invoice_num'];
        $payer_email = $_POST['x_email'];
        switch ($payment_status) {
            case 1:
                $updated_status = 'paid';
                break;
            case 2:
                $updated_status = 'cancelled';
                break;
            case 3:
                $updated_status = 'cancelled';
                break;
            case 4:
                $updated_status = 'received';
                break;
            default:
                $updated_status = 'cancelled';
                break;
        }
        $dukapress->update_order_status($invoice, $updated_status);
        DukaPress_Mail::payment_mail($invoice);
    }

}
?>