<?php
/*
 * Dukapress Image Effects
 *
 */

if (!function_exists('dp_img_resize')) :

	/**
	 * Handle the Image resizing
	 * @param Integer $attach_id - The id of the image
	 * @param String $img_url - The full URL to the image
	 * @param Integer $width - The width of the image
	 * @param Integer $height - The height of the image
	 * @param Boolean $crop - Crop the image or not
	 *
	 * return String - returns image url resized
	 * */
	function dp_img_resize($attach_id = null, $img_url = null, $width = false, $height = false, $crop = false){
		if(($width && $height) && !(empty($width) && empty($height))){
			if($attach_id){
				// this is an attachment, so we have the ID
				$image_src = wp_get_attachment_image_src($attach_id, 'full');
				$file_path = get_attached_file($attach_id);
			} else if($img_url && is_string($img_url)){
				// this is not an attachment, let's use the image url
				$file_path = parse_url($img_url);
				$file_path = $_SERVER['DOCUMENT_ROOT'].$file_path['path'];
				// Look for Multisite Path
				if(file_exists($file_path) === false){
					global $blog_id;
					$file_path = parse_url($img_url);
					if(preg_match('/files/', $file_path['path'])){
						$path = explode('/', $file_path['path']);
						foreach($path as $k => $v){
							if($v == 'files'){
								$path[$k-1] = 'wp-content/blogs.dir/'.$blog_id;
							}
						}
						$path = implode('/', $path);
					}
					$file_path = $_SERVER['DOCUMENT_ROOT'].$path;
				}
				$orig_size = getimagesize($file_path);
				$image_src[0] = $img_url;
				$image_src[1] = $orig_size[0];
				$image_src[2] = $orig_size[1];
			}
			if(dp_is_image($file_path)){
				$file_info = pathinfo($file_path);
				// check if file exists
				$base_file = $file_info['dirname'].'/'.$file_info['filename'].'.'.$file_info['extension'];
				if(!file_exists($base_file))
				return;
				$extension = '.'. $file_info['extension'];
				// the image path without the extension
				$no_ext_path = $file_info['dirname'].'/'.$file_info['filename'];
				$cropped_img_path = $no_ext_path.'-'.$width.'x'.$height.$extension;
				if(file_exists($cropped_img_path))
					if(time() - @filemtime(utf8_decode($cropped_img_path)) >= 2*24*60*60){
						unlink($cropped_img_path);
					}
                
				// checking if the file size is larger than the target size
				// if it is smaller or the same size, stop right here and return
				if($image_src[1] > $width){
					// the file is larger, check if the resized version already exists (for $crop = true but will also work for $crop = false if the sizes match)
					if(file_exists($cropped_img_path)){
						$cropped_img_url = str_replace(basename($image_src[0]), basename($cropped_img_path), $image_src[0]);
						$dp_image = array(
							'url'   => $cropped_img_url,
							'width' => $width,
							'height'    => $height
						);
						return $dp_image['url'];
					}
					// $crop = false or no height set
					if($crop == false OR !$height){
						// calculate the size proportionaly
						$proportional_size = wp_constrain_dimensions($image_src[1], $image_src[2], $width, $height);
						$resized_img_path = $no_ext_path.'-'.$proportional_size[0].'x'.$proportional_size[1].$extension;
						// checking if the file already exists
						if(file_exists($resized_img_path)){
							$resized_img_url = str_replace(basename($image_src[0]), basename($resized_img_path), $image_src[0]);
							$dp_image = array(
								'url'   => $resized_img_url,
								'width' => $proportional_size[0],
								'height'    => $proportional_size[1]
							);
							return $dp_image['url'];
						}
					}
					// check if image width is smaller than set width
					$img_size = getimagesize($file_path);
					if($img_size[0] <= $width) $width = $img_size[0];
					// Check if GD Library installed
					if(!function_exists('imagecreatetruecolor')){
						echo 'GD Library Error: imagecreatetruecolor does not exist - please contact your webhost and ask them to install the GD library';
						return;
					}
					
					$new_img_path = wp_get_image_editor($file_path);
					if ( ! is_wp_error( $new_img_path ) ) {
						$new_img_path->resize( $width, $height, $crop );
						$filename = $new_img_path->generate_filename();
						$new_img_path->save($filename);

						// no cache files - let's finally resize it
						$new_img = str_replace(basename($image_src[0]), basename($filename), $image_src[0]);

						return $new_img;
					}else{
						return $img_url;
					}
				}
				return $image_src[0];
			}
		}else{
			return $img_url;
		}

	}
endif;


if(!function_exists('dp_is_image')):

	/*
	 * Verify that the given path is indeed an image
	 */
	function dp_is_image($path){
		if($path){
			$a = @getimagesize($path);
			$image_type = $a[2];

			if(in_array($image_type , array(IMAGETYPE_GIF , IMAGETYPE_JPEG ,IMAGETYPE_PNG , IMAGETYPE_BMP))){
				return true;
			}
		}
		return false;
	}
endif;

function dp_pnj_mz_effect($attachment_images, $product_id) {
    global $dukapress;

    $output = '<div class="dpsc_image_section">';
    $output .= '<div class="dpsc_image_tab">';
    $output .= '<ul class="dpsc_tabs">';
    $count = 0;
    foreach ($attachment_images as $image) {
		$image_src = wp_get_attachment_url($image->ID,'full');
        if ($count === 0) {
			$main_image_id = $image->ID;
        }
        $output .= '<li><a class="dpsc_thumb_tab" id="' . $product_id . '" href="' . $image_src . '" onclick="return false;"><img src="'.dp_img_resize($image->ID, null, $dukapress->get_setting('thumb_img_width'), $dukapress->get_setting('thumb_img_height')).'" ></a></li>';
        $count++;
    }
    $output .= '</ul>';
    $output .= '</div>';
    $output .= '<div class="dpsc_main_image main_' . $product_id . '">';
    $output .= '<a href="' . wp_get_attachment_url($main_image_id,'full') . '" class="MagicZoom" id="zoom1" rel="show-title: false; zoom-fade: true; zoom-position: inner; thumb-change: mouseover" onclick="return false;"><img src="' .dp_img_resize($main_image_id, null, $dukapress->get_setting('product_img_width'), $dukapress->get_setting('product_img_height')). '" ></a>';
    $output .= '</div>';
    $output .= '</div>';
    return $output;
}

function dp_pnj_jqzoom_effect($attachment_images, $product_id) {
    global $dukapress;

    $output = '<div class="dpsc_image_section">';
    $output .= '<div class="dpsc_image_tab">';
    $output .= '<ul class="dpsc_tabs">';
    $count = 0;
    foreach ($attachment_images as $image) {
		$image_src = wp_get_attachment_url($image->ID,'full');
        if ($count === 0) {
			$main_image_id = $image->ID;
        }
        $output .= '<li><a class="dpsc_thumb_tab" id="' . $product_id . '" href="' . $image_src . '" onclick="return false;"><img src="' .dp_img_resize($image->ID, null, $dukapress->get_setting('thumb_img_width'), $dukapress->get_setting('thumb_img_height')). '" ></a></li>';
        $count++;
    }
    $output .= '</ul>';
    $output .= '</div>';
    $output .= '<div class="dpsc_main_image main_' . $product_id . '">';
    $output .= '<a href="' . wp_get_attachment_url($main_image_id,'full') . '" title="image" class="dp_jqzoom" onclick="return false;"><img src="' .dp_img_resize($main_image_id, null, $dukapress->get_setting('product_img_width'), $dukapress->get_setting('product_img_height')). '" ></a>';
    $output .= '</div>';
    $output .= '</div>';
    return $output;
}

function dp_pnj_lightbox_effect($attachment_images, $product_id) {
    global $dukapress;

    $output = '<div class="dpsc_image_section">';
    $output .= '<div class="dpsc_image_tab">';
    $output .= '<ul class="dpsc_tabs">';
    $count = 0;
    foreach ($attachment_images as $image) {
		$image_src = wp_get_attachment_url($image->ID,'full');
        if ($count === 0) {
			$main_image_id = $image->ID;
        }
        $output .= '<li><a class="dpsc_thumb_tab fancybox" id="' . $product_id . '" rel="imgGroup" href="' . $image_src . '" onclick="return false;"><img src="' . dp_img_resize($image->ID, null, $dukapress->get_setting('thumb_img_width'), $dukapress->get_setting('thumb_img_height')). '" ></a></li>';
        $count++;
    }
    $output .= '</ul>';
    $output .= '</div>';
    $output .= '<div class="dpsc_main_image main_' . $product_id . '">';
    $output .= '<a href="' . wp_get_attachment_url($main_image_id,'full') . '" class="fancybox theProdMedia theProdMedia_alt"  rel="imgGroup" onclick="return false;"><img src="' . dp_img_resize($main_image_id, null, $dukapress->get_setting('product_img_width'), $dukapress->get_setting('product_img_height')). '" ></a>';
    $output .= '</div>';
    $output .= '</div>';
    return $output;
}

function dp_pnj_no_effect($attachment_images, $product_id) {
    global $dukapress;

    $output = '<div class="dpsc_image_section">';
    $output .= '<div class="dpsc_image_tab">';
    $output .= '<ul class="dpsc_tabs">';
    $count = 0;
    foreach ($attachment_images as $image) {
		$image_src = wp_get_attachment_url($image->ID,'full');
        if ($count === 0) {
			$main_image_id = $image->ID;
        }
        $output .= '<li><a class="dpsc_thumb_tab" id="' . $product_id . '" href="' . $image_src . '" onclick="return false;"><img src="' . dp_img_resize($image->ID, null, $dukapress->get_setting('thumb_img_width'), $dukapress->get_setting('thumb_img_height')) . '" ></a></li>';
        $count++;
    }
    $output .= '</ul>';
    $output .= '</div>';
    $output .= '<div class="dpsc_main_image main_' . $product_id . '">';
    $output .= '<img src="' . dp_img_resize($main_image_id, null, $dukapress->get_setting('product_img_width'), $dukapress->get_setting('product_img_height')). '" >';
    $output .= '</div>';
    $output .= '</div>';
    return $output;
}
?>
