<?php
/**
 * Template Helpers
 */


if (!function_exists('dukapress_product_detail')) :

	/**
	 * Returns the Dukapress Product Detail that can be used in different views and for the Product Page
	 * @param $id - The Product ID
	 *
	 * */
	function dukapress_product_detail($id = false){
		global $dukapress;

		$product_fields_output = array();

		//If the ID is not set or is false we get the default Page id
		if(!$id){
			$id = get_the_ID();
		}

		$meta = get_post_custom($id);
		foreach ( $meta as $key => $val ) {
			$meta[ $key ] = maybe_unserialize( $val[ 0 ] );
			if (!is_array($meta[$key]) && $key != "duka_is_sale" && $key != "duka_track_inventory" && $key != "duka_product_link")
				$meta[$key] = array($meta[$key]);
		}

		$product_fields_output['id'] = $id;
		$product_fields_output['name'] = get_the_title($id);
		$product_fields_output['content'] = get_post_field('post_content', $id);
		
		//Price
		if ( isset( $meta[ "price" ] ) && is_array( $meta[ "price" ] ) ) {
			foreach ( $meta[ "price" ] as $key => $value ) {
				if ( isset( $meta[ "new_price" ] ) && $meta[ "new_price" ] ) {
					$product_fields_output['price'] = $dukapress->format_currency( '', $value ) ;
					$product_fields_output['new_price'] = $dukapress->format_currency( '', $meta[ "new_price" ][ $key ] ) ;
					$product_fields_output['c_price'] = $value ;
					$product_fields_output['c_new_price'] = $meta[ "new_price" ][ $key ];
					$product_fields_output['final_price'] = $product_fields_output['new_price'];
				} else {
					$product_fields_output['price'] = $dukapress->format_currency( '', $value ) ;
					$product_fields_output['new_price'] = '';
					$product_fields_output['c_price'] = $value ;
					$product_fields_output['c_new_price'] = '';
					$product_fields_output['final_price'] = $value;
				}
			}
		} else {
			$product_fields_output['price'] = $dukapress->format_currency( '', 0 );
		}

		//Weight
		if ( isset( $meta[ "item_weight" ] ) && is_array( $meta[ "item_weight" ] ) ) {
			foreach ( $meta[ "item_weight" ] as $key => $value ) {
				$product_fields_output['item_weight'] = $value;
			}
		}else{
			$product_fields_output['item_weight'] = '';
		}

		//Stock
		if ( isset( $meta[ "currently_in_stock" ] ) && $meta[ "currently_in_stock" ] ) {
			foreach ( (array) $meta[ "currently_in_stock" ] as $value ) {
				$inventory	 = ($value) ? $value : 0;
				$product_fields_output['stock'] = number_format_i18n( $inventory );
			}
		}

		//Affiliate URL
		if ( isset( $meta[ "affiliate_url" ] ) && $meta[ "affiliate_url" ] ) {
			foreach ( (array) $meta[ "affiliate_url" ] as $value ) {
				$product_fields_output['affiliate_url'] = $value;
			}
		}

		//Variations
		if ( isset( $meta[ "dropdown_option" ] ) && is_array( $meta[ "dropdown_option" ] ) ) {
			$dropdown_content = '<div class="dpsc_variation_main">';
			foreach ( $meta[ "dropdown_option" ] as $key => $value ) {
				$get_vars = explode('||', $value);
				$div_var_id = 0;
				foreach ($get_vars as $get_var) {
					$pro_vars = explode('|', $get_var);
					$vari_name = $pro_vars[0];
					if(!empty($vari_name))
						$dropdown_content .= '<div id="dpsc_variation_' . $div_var_id . '" class="dpsc_variation"><span class="dpsc_variation" for="var">' . __('Select','dp-lang') . ' ' . __(dpsc_variation_name($vari_name)) . ' </span>';
					$pro_vars = array_slice($pro_vars, 1);
                    if(!empty($pro_vars)){
                        $dropdown_content .= '<select class="dpsc_variation_select" name="var[]" onchange="dpsc_variation_price(this,\''.$id.'\',\'dpsc_product_form_'.$id.'\')">';
                        //$dropdown_content .= '<option value="">' . __('Select','dp-lang') . '</option>';
                        $dropdown_content . '</option>';
                        foreach ($pro_vars as $pro_var) {
                          $get_var = explode(';', $pro_var);
                          $var_price_text = '';
                          if (isset($get_var[1])) {
                              $var_price = floatval($get_var[1]);
                              $var_price_display = number_format(floatval($get_var[1]), 2);
                          }
                          $dropdown_content .= '<option data-price="' . $var_price . '" value="' . $get_var[0] . ',:_._:,' . $var_price . '">' . $get_var[0] . $var_price_text . '</option>';
                          $dropdown_content . '</option>';
                        }
                        $dropdown_content .= '</select></div><div class="clear"></div>';
                    }
					$div_var_id++;
				}
			}
			$dropdown_content .= '</div><div class="clear"></div>';
			$product_fields_output['dropdown'] = $dropdown_content;
		}

		$attachment_images = get_attached_media('image', $id);
		if (is_array($attachment_images) && count($attachment_images) > 0) {
			$image_effect = $dukapress->get_setting('image_effect');
			$image_content = $image_content = dp_pnj_no_effect($attachment_images, $id);
			switch ($image_effect) {
				case 'mz_effect':
					$image_content = dp_pnj_mz_effect($attachment_images, $id);
					break;

				case 'mzp_effect':
					$image_content = dp_pnj_mz_effect($attachment_images, $id);
					break;

				case 'lightbox':
					$image_content = dp_pnj_lightbox_effect($attachment_images, $id);
					break;

				case 'no_effect':
					$image_content = dp_pnj_no_effect($attachment_images, $id);
					break;

				case 'jqzoom_effect':
					$image_content = dp_pnj_jqzoom_effect($attachment_images, $id);
					break;

				default:
					$image_content = dp_pnj_no_effect($attachment_images, $id);
					break;
			}
			$product_fields_output['image_output'] = $image_content;
		}

		return $product_fields_output;

	}
endif;

if (!function_exists('dukapress_product_images')) :

	/**
	 * Display the produce images only
	 *
	 * */
	function dukapress_product_images($id = false){

		global $dukapress;

		//If the ID is not set or is false we get the default Page id
		if(!$id){
			$id = get_the_ID();
		}

		$content = '<div class="dpsc_image_container">';

		$attachment_images =  get_attached_media( 'image', $id);
        if (is_array($attachment_images) && count($attachment_images) > 0) {
        	$image_effect = $dukapress->get_setting('image_effect');
        	$image_content = $image_content = dp_pnj_no_effect($attachment_images, $id);
        	switch ($image_effect) {
                case 'mz_effect':
                    $image_content = dp_pnj_mz_effect($attachment_images, $id);
                    break;

                case 'mzp_effect':
                    $image_content = dp_pnj_mz_effect($attachment_images, $id);
                    break;

                case 'lightbox':
                    $image_content = dp_pnj_lightbox_effect($attachment_images, $id);
                    break;

                case 'no_effect':
                    $image_content = dp_pnj_no_effect($attachment_images, $id);
                    break;

                case 'jqzoom_effect':
                    $image_content = dp_pnj_jqzoom_effect($attachment_images, $id);
                    break;

                default:
					$image_content = dp_pnj_no_effect($attachment_images, $id);
                    break;
            }
            $content .= $image_content;
        }
        $content .= '<div class="clear"></div>';
        return $content;

	}

endif;


if (!function_exists('dukapress_product_price')) :

	/**
	 * Use this to show the price of a product
	 *
	 * */
	function dukapress_product_price($id = false){
		global $dukapress;

		//If the ID is not set or is false we get the default Page id
		if(!$id){
			$id = get_the_ID();
		}

		$meta = get_post_custom($id);
		foreach ( $meta as $key => $val ) {
			$meta[ $key ] = maybe_unserialize( $val[ 0 ] );
		}

		$content = "";
		//Price
		if ( isset( $meta[ "price" ] ) && is_array( $meta[ "price" ] ) ) {
			foreach ( $meta[ "price" ] as $key => $value ) {
				$content_price = '';
				$price = $dukapress->format_currency( '', $value ) ;
				$new_price = $dukapress->format_currency( '', 0 );
				if ( isset( $meta[ "new_price" ] ) && $meta[ "new_price" ] ) {
					$new_price = $dukapress->format_currency( '', $meta[ "new_price" ][ $key ] ) ;

					$content_price = '<p class="dpsc_price" id="dpsc_price">' . __('Price', "dp-lang") . ': <span class="was">' . $price . '</span>&nbsp;<span class="is">' . $new_price . '</span></p>';
				} else {
					$content_price = '<p class="dpsc_price" id="dpsc_price">' . __('Price', "dp-lang") . ': ' . $price. '</p>';
				}
				$content = $content_price;
				$content = apply_filters( 'dukapress_single_product_price', $content_price, $id, $price, $new_price);
			}
		} else {
			$content = '<p class="dpsc_price">' . __('Price', "dp-lang") . ': ' . $dukapress->format_currency( '', 0 ). '</p>';
		}

		return $content;

	}

endif;


if (!function_exists('dukapress_product_cart_action')) :

	/**
	 * Generate the Add To Cart button for each product
	 *
	 * */
	function dukapress_product_cart_action($output,$buy_now = false,$affiliate_checkout = false){
		global $dukapress;

		$product_id = $output['id'];

		$disabled_add_to_cart = '';

	    if(isset($output['stock'])){
	    	if ( $dukapress->get_setting( 'inventory_remove' ) && $output['stock'] <= 0 ) {
	    		$disabled_add_to_cart = 'disabled="disabled"';
	    	}
	    }


		$cart_form = "";
		$form_id = 'dpsc_product_form_' . $product_id;

		$cart_form = '<form id="' . $form_id . '" name="dpsc_product_form_' . $product_id . '" class="dcps_product_form">';
        if(isset($output['dropdown']))
		  $cart_form .= $output['dropdown'];
		$cart_form .= '<input type="hidden" name="product_id" value="' . $product_id . '"/>';
		$cart_form .= '<input type="hidden" name="product_weight" value="' . $output['item_weight'] . '"/>';
		$cart_form .= '<input type="hidden" id="dpsc_actual_price_'.$product_id.'" value="' . $output['c_price'] . '"/>';
		$cart_form .= '<input type="hidden" id="dpsc_new_product_price_'.$product_id.'" value="' . $output['c_new_price'] . '"/>';
        $cart_form .= '<input type="hidden" name="save_cart" value="1"/>';
		$cart_form .= '<input type="hidden" id="dpsc_new_product_price_hidden" name="dpsc_price_updated" value="' . $output['final_price'] . '" />';
		$dpscaction = 'normal';
		$button_action = __('Add to Cart', "dp-lang");

		//Direct to cart
		if ($buy_now) {
            $button_action = __('Buy Now', "dp-lang");
            $dpscaction = 'dpsc_direct';
        }

		//redirect to Affiliate
		if ($affiliate_checkout) {
			$button_action = __('Buy Now', "dp-lang");
			$dpscaction = 'dpsc_affiliate';
		}

		if ($dukapress->get_setting( 'dp_shop_mode' ) === 'inquiry') {
			$button_action = __('Inquire', "dp-lang");
		}
        $cart_form .= '<input type="hidden" name="dpsc_action" value="'.$dpscaction.'"/>';
		$cart_form .= '<input type="hidden" name="action" value="dpsc_update_cart"/>';
		$cart_form .= '<input type="submit" '.$disabled_add_to_cart.' class="dpsc_submit_button" id="dpsc_submit_button_' . $product_id . '" name="dpsc_add_to_cart" value="' . $button_action . '"/>';
		$cart_form .= '</form>';
		return $cart_form;
	}

endif;


if (!function_exists('dukapress_single_product')) :

	/**
	 * Display single product page
	 *
	 * @param Boolean $images - Show images. Default true
	 * @param Boolean $buy_now - Send directly to cart
	 * @param Boolean $affiliate_checkout - Redirect to affiliate URL
	 * @param Boolean $echo - Print contents or return html
	 *
	 * */
	function dukapress_single_product($images = true,$buy_now = false,$affiliate_checkout = false, $echo = false){
		global $dukapress;
		$output = dukapress_product_detail();
		$content = '<div class="dpsc_product_main_container single_product'.$output['id'].'">';
	    if($images){
		    $content .= '<div class="dpsc_image_container">';
            if(isset($output['image_output']))
		      $content .= $output['image_output'];
		    $content .= '</div>';
		}
	    $content .= '<div class="dpsc_content_container">';
	    if(isset($output['price'])){
			$price = $output['price'];
			$new_price = "";
			$content_price = "";
	    	if($output['new_price']){
	    		$content_price .= '<p class="dpsc_price" id="dpsc_price">' . __('Price', "dp-lang") . ': <span class="was">' . $output['price'] . '</span>&nbsp;<span class="is">' . $output['new_price'] . '</span></p>';
				$new_price = $output['new_price'];
	    	}else
	    		$content_price .= '<p class="dpsc_price" id="dpsc_price">' . __('Price', "dp-lang") . ': ' . $price . '</p>';
				
				
			$content .= apply_filters( 'dukapress_single_product_price', $content_price, $output['id'], $price, $new_price);
	    }


	    if(isset($output['stock'])){
	    	if ( $dukapress->get_setting( 'inventory_remove' ) && $output['stock'] <= 0 ) {
	    		$content  .= '<span class="dpsc_in_stock_sold_out">' . __('Out of Stock', "dp-lang") . '</span>';
	    	}else {
	    		$content  .= '<span class="dpsc_in_stock">' . __('Currently in Stock', "dp-lang") . '</span>';
	    	}
	    }

	    $product_id = $output['id'];
	    $product_name = $output['name'];

		$cart_form = dukapress_product_cart_action($output,$buy_now,$affiliate_checkout);

        $content .= $cart_form;
        if($echo)
        	echo $content;
        else
        	return $content;

	}
endif;


if (!function_exists('dukapress_products_view')) :

	/**
	 * Display products
	 *
	 * @param Array $products - Array of products
	 * @param Integer $column - Number of columns
	 * @param String $view - PRoduct view. Either list or grid. Defaults to grid
	 * @param Boolean $buy_now - Send directly to cart
	 * @param Boolean $affiliate_checkout - Redirect to affiliate URL
	 * @param Boolean $echo - Print contents or return html
	 *
	 * */
	function dukapress_products_view($products, $column, $view="grid", $buy_now = false,$affiliate_checkout = false, $echo = false, $images = false){
		global $dukapress;
		$content = '';
		if (is_array($products) && count($products) > 0) {
			$content .= '<div class="dpsc_'.$view.'_display">';
			$count = 1;
			foreach ($products as $product) {
				$output = dukapress_product_detail($product->ID);
				if($images){
					$attachment_images =  get_attached_media( 'image', $product->ID);;
					$main_image = false;
					foreach ($attachment_images as $image) {
						$main_image = $image->ID;
						break;
					}
					if(!$main_image){
						$main_image = get_post_thumbnail_id( $product );
					}
				}
				$prod_permalink = get_permalink($product->ID);
				$content .= '<div class="dpsc_'.$view.'_product single_product'.$output['id'].'">';
				if($images){
					$content .= '<div class="dpsc_'.$view.'_product_image">';
					if ($main_image) {
						$content .= '<a href="' . $prod_permalink . '" title="' . $product->post_title . '"><img src="' . dp_img_resize($main_image, null, $dukapress->get_setting('grid_img_width'), $dukapress->get_setting('grid_img_height')). '" ></a>';
					}else{
						$content .= '<a href="' . $prod_permalink . '" title="' . $product->post_title . '"><img src="' . DPSC_DUKAPRESS_RESOURCEURL. '/img/default_product_small.jpg" style="width:'.$dukapress->get_setting('grid_img_width').' px;"></a>';
					}
					$content .= '</div>';
				}
				$content .= '<div class="dpsc_'.$view.'_product_detail">';
				$content .= '<p class="title"><a href="' . $prod_permalink . '" title="' . $product->post_title . '">' . __($product->post_title) . '</a></p>';
				$content .= '<p class="detail">' . $dukapress->product_excerpt( $product->post_excerpt, $product->post_content, $product->ID ) . '</p>';
				if($output['price']){
			    	if($output['new_price']){
			    		$content .= '<p class="dpsc_price" id="dpsc_price">' . __('Price', "dp-lang") . ': <span class="was">' . $output['price'] . '</span>&nbsp;<span class="is">' . $output['new_price'] . '</span></p>';
			    	}else
			    		$content .= '<p class="dpsc_price" id="dpsc_price">' . __('Price', "dp-lang") . ': ' . $output['price'] . '</p>';
			    }
			    $cart_form = dukapress_product_cart_action($output,$buy_now,$affiliate_checkout);
			    $content .= $cart_form;
			    $content .= '</div></div>';
			    if($view === "grid"){
				    if ($count === intval($column)) {
						$content .= '<div class="clear"></div>';
						$count = 0;
					}
				}
				$count++;
			}
			$content .= '</div>';
		}

		if($echo)
        	echo $content;
        else
        	return $content;
	}

endif;


if (!function_exists('dukapress_products_page_display')) :

	/**
	 * Display products on a page with Pagination
	 * Returns a HTML string
	 *
	 * @param Integer $category - The category of the product
	 * @param Integer $total - The total number of products to show
	 * @param Integer $column - The number of columns. This is mainly for Grid views
	 * @param Integer $per_page - The number of products to show per page
	 * @param String $order - The order of the products. ASC for ascending and DESC for descending. Defaults to DESC
	 * @param Boolean $buy_now - Set the products to send a user directly to the cart
	 * @param Boolean $affiliate - If set to true, we will redirect all product purchases to the affilaite url
	 * @param String $view - The display of the product. Either grid or list. Default is grid
	 * @param String $exclude - Comma seperated ids of products to be exclude from the list
	 *
	 * */
	function dukapress_products_page_display($category, $total, $column, $per_page, $order = 'DESC', $buy_now = false, $affiliate = false, $view = 'grid', $exclude = '', $images = true){

		$post_offset = 1;
		if (!empty($per_page) && !empty($total)) {
			$pagenum = isset($_GET['dpage']) ? $_GET['dpage'] : 1;

			$pagination_array = array(
                    'base' => add_query_arg('dpage', '%#%'),
                    'format' => '',
                    'prev_text' => __('&laquo;'),
                    'next_text' => __('&raquo;'),
                    'total' => ceil($total / $per_page),
                    'current' => $pagenum,
					'add_args' => false
                );
			$page_links = paginate_links($pagination_array);

	        $post_offset = ($pagenum - 1) * $per_page;
	        $offset = '&offset=' . $post_offset;
	        $page_links = '<div class="dpsc_grid_pagination">' . $page_links . '</div>';
		}else if(empty($total) && !empty($per_page)){

			$total_products = wp_cache_get( 'duka_total_products_display', 'counts' );
			if(false == $total_products){
				$args = array(
					'posts_per_page'   => -1,
					'post_type'        => 'duka',
					'post_status'      => 'publish'
				);

				if(!empty($category)){
					$args['tax_query'] = array(
						'relation' => 'AND',
							array(
								'taxonomy' => 'duka_category',
								'field'    => 'term_id',
								'terms'    =>  $category,
							),
						'relation' => 'OR',
							array(
								'taxonomy' => 'duka_tag',
								'field'    => 'term_id',
								'terms'    =>  $category,
							),
					);
				}

				$posts_array = new WP_Query();
				$total_products = $posts_array->query($args);

				$total_products = count($total_products);
				wp_cache_set( 'duka_total_products_display', $total_products);
			}

			$pagenum = isset($_GET['dpage']) ? $_GET['dpage'] : 1;

			$pagination_array = array(
                    'base' => add_query_arg('dpage', '%#%'),
                    'format' => '',
                    'prev_text' => __('&laquo;'),
                    'next_text' => __('&raquo;'),
                    'total' => ceil($total_products / $per_page),
                    'current' => $pagenum,
					'add_args' => false
                );
			$page_links = paginate_links($pagination_array);

	        $post_offset = ($pagenum - 1) * $per_page;
	        $offset = '&offset=' . $post_offset;
	        $page_links = '<div class="dpsc_grid_pagination">' . $page_links . '</div>';
		}else {
	        $per_page = $total;
	        $offset = '';
	        $page_links = '';
	    }
	    

		$args = array(
			'posts_per_page'   => $per_page,
			'post_type'        => 'duka',
			'post_status'      => 'publish',
		);

		if ($order != 'rand') {
	        $args['orderby'] = 'post_date';
			$args['order'] = $order;
	    } else {
			$args['orderby'] = 'rand';
	    }

		if(!empty($offset)){
			$args['offset'] = $post_offset;
		}

		if(!empty($category)){
			$args['tax_query'] = array(
				'relation' => 'AND',
					array(
						'taxonomy' => 'duka_category',
						'field'    => 'term_id',
						'terms'    =>  $category,
					),
				'relation' => 'OR',
					array(
						'taxonomy' => 'duka_tag',
						'field'    => 'term_id',
						'terms'    =>  $category,
					),
					
			);
		}

		$posts_array = new WP_Query();
		$products = $posts_array->query($args);

	    $content = dukapress_products_view($products, $column, $view, $buy_now,$affiliate, false, $images);

	    $content .= '<div class="clear"></div>' . $page_links . '<div class="clear"></div>';

	    return $content;
	}

endif;
?>
