<?php
class Dukapress_PostColumns{

  static function init(){
    add_filter('manage_duka_posts_columns', array(__CLASS__, 'manage_duka_columns'));
    add_action('manage_duka_posts_custom_column', array(__CLASS__, 'edit_duka_custom_columns'), 10, 2);
    add_action('restrict_manage_posts', array(__CLASS__, 'edit_duka_filter'));
    add_action( 'manage_posts_extra_tablenav', array(__CLASS__, 'orders_extra_button'));
      

    add_filter('post_row_actions', array(__CLASS__, 'edit_duka_custom_row_actions'), 10, 2);
    add_filter('admin_action_copy-duka', array(__CLASS__, 'edit_products_copy_action'));

    //manage orders page
    add_filter('manage_duka_order_posts_columns', array(__CLASS__, 'manage_orders_columns'));
    add_action('manage_duka_order_posts_custom_column', array(__CLASS__, 'manage_orders_custom_columns'));
      
    //Handle the Order status 
    add_action( 'admin_init', array(__CLASS__, 'manage_orders_custom_actions'));
      
  }
  /**
   * Product View custom Columns
   *
   */
  static function manage_duka_columns($old_columns) {
      global $post_status;
      global $dukapress;
      $columns['cb'] = '<input type="checkbox" />';
      $columns['thumbnail'] = __('Thumbnail', 'dp-lang');
      $columns['title'] = __('Product Name', 'dp-lang');
      $columns['sku'] = __('SKU', 'dp-lang');
      $columns['pricing'] = __('Price', 'dp-lang');
      if (!$dukapress->get_setting('disable_cart')) {
          if ($dukapress->get_setting('inventory_active'))
            $columns['stock'] = __('Stock', 'dp-lang');
          $columns['sales'] = __('Sales', 'dp-lang');
      }
      $columns['product_categories'] = __('Product Categories', 'dp-lang');
      $columns['product_tags'] = __('Product Tags', 'dp-lang');
      return $columns;
  }

  /**
   * Loads Data into the custom columns
   *
   *
   */
  static function edit_duka_custom_columns($column, $id) {
      global $post;
      global $dukapress;

      $meta = get_post_custom();

      //unserialize
      foreach ($meta as $key => $val) {
          $meta[$key] = maybe_unserialize($val[0]);
          if (!is_array($meta[$key]) && $key != "duka_is_sale" && $key != "duka_track_inventory" && $key != "duka_product_link")
            $meta[$key] = array($meta[$key]);
      }

      switch ($column) {
          case "thumbnail":
              echo '<a href="' . get_edit_post_link() . '" title="' . __('Edit &raquo;') . '">';
              if (has_post_thumbnail()) {
                  echo '<img src="' .dp_img_resize(get_post_thumbnail_id(), '', 70, 70).'"/>';
              }
              else {
                  echo '<img width="70" height="70" src="' . DPSC_DUKAPRESS_RESOURCEURL . '/img/default_product_small.jpg">';
              }
              echo '</a>';
              break;

          case "sku":
              if (isset($meta["duka_sku"]) && is_array($meta["duka_sku"])) {
                  foreach ((array)$meta["duka_sku"] as $value) {
                      echo esc_attr($value) . '<br />';
                  }
              }
              else {
                  _e('N/A', 'dp-lang');
              }
              break;

          case "pricing":
              if (isset($meta["price"]) && is_array($meta["price"])) {
                  foreach ($meta["price"] as $key => $value) {
                      if (isset($meta["new_price"]) && $meta["new_price"]) {
                          echo '<del>' . $dukapress->format_currency('', $value) . '</del> ';
                          echo $dukapress->format_currency('', $meta["new_price"][$key]) . '<br />';
                      }
                      else {
                          echo $dukapress->format_currency('', $value) . '<br />';
                      }
                  }
              }
              else {
                  echo $dukapress->format_currency('', 0);
              }
              break;

          case "sales":
              echo number_format_i18n(isset($meta["duka_sales_count"][0]) ? $meta["duka_sales_count"][0] : 0);
              break;

          case "stock":
              if (isset($meta["currently_in_stock"]) && $meta["currently_in_stock"]) {
                  foreach ((array)$meta["currently_in_stock"] as $value) {
                      $inventory = ($value) ? $value : 0;
                      if ($inventory == 0) $class = 'duka-inv-out';
                      else if ($inventory <= $dukapress->get_setting('inventory_threshhold')) $class = 'duka-inv-warn';
                      else $class = 'duka-inv-full';

                      echo '<span class="' . $class . '">' . number_format_i18n($inventory) . '</span><br />';
                  }
              }
              else {
                  _e('N/A', 'dp-lang');
              }
              break;

          case "product_categories":
              echo dukapress_category_list($id);
              break;

          case "product_tags":
              echo dukapress_tag_list($id);
              break;
          }
      }

    /**
     * Adds filter by Product Category
     *
     */
    static function edit_duka_filter() {
        global $current_screen;
        if ($current_screen->id == 'edit-duka') {
            $selected_category = !empty($_GET['duka_category']) ? $_GET['duka_category'] : null;
            $dropdown_options = array('taxonomy' => 'duka_category', 'show_option_all' => __('View all categories'), 'hide_empty' => 0, 'hierarchical' => 1, 'show_count' => 0, 'orderby' => 'name', 'name' => 'duka_category', 'selected' => $selected_category);
            wp_dropdown_categories($dropdown_options);
        }
    }
    
    
    /** 
     * Add Button for Delete All Orders
     */
    static function orders_extra_button($which) {
        global $current_screen;
        if ( 'top' === $which) 
            if('duka_order' == $current_screen->post_type){
                submit_button( __( 'Delete All','dp-lang' ), 'apply', 'delete_all', false );
            }
    }
    
    /**
     * change the order status
     */
    static function manage_orders_custom_actions(){
        if ( isset( $_REQUEST['duka_order_status'] )){
            global $dukapress;
            $status = $_REQUEST['duka_order_status'];
            $post_id = $_REQUEST['post_id'];
            $dukapress->update_order_status($post_id, $status);
        }
    }

    /**
     * Adds a custom row action for Copying/Cloning a Product
     *
     */
    static function edit_duka_custom_row_actions($actions, $post) {
        $action = 'copy-duka';

        if (($post->post_type == "duka") && (!isset($actions[$action]))) {

            $post_type_object = get_post_type_object($post->post_type);
            if ($post_type_object) {
                if (current_user_can('edit_pages')) {
                    $copy_link = add_query_arg('action', $action);
                    $copy_link = add_query_arg('post', $post->ID, $copy_link);
                    $copy_link = wp_nonce_url($copy_link, "{$action}-{$post->post_type}_{$post->ID}");
                    $actions[$action] = '<a href="' . $copy_link . '">' . __('Copy', 'dp-lang') . '</a>';
                }
            }
        }else if($post->post_type == "duka_order"){
            unset( $actions['inline hide-if-no-js'] );
            unset( $actions['view'] );
            $trash_link = get_delete_post_link($post->ID);
            $paid_url = add_query_arg(
                array(
                  'post_id' => $post->ID,
                  'duka_order_status' => 'paid',
                )
            );
            $shipped_url = add_query_arg(
                array(
                  'post_id' => $post->ID,
                  'duka_order_status' => 'shipped',
                )
            );
            $closed_url = add_query_arg(
                array(
                  'post_id' => $post->ID,
                  'duka_order_status' => 'closed',
                )
            );
            $received_url = add_query_arg(
                array(
                  'post_id' => $post->ID,
                  'duka_order_status' => 'received',
                )
            );
            if ($post->post_status == 'order_received') {
                  $actions['paid'] = "<a title='" . esc_attr(__('Mark as Paid', 'dp-lang')) . "' href='" . esc_url( $paid_url ) . "'>" . __('Paid', 'dp-lang') . "</a>";
                  $actions['shipped'] = "<a title='" . esc_attr(__('Mark as Shipped', 'dp-lang')) . "' href='" . esc_url( $shipped_url ) . "'>" . __('Shipped', 'dp-lang') . "</a>";
                  $actions['closed'] = "<a title='" . esc_attr(__('Mark as Closed', 'dp-lang')) . "' href='" . esc_url( $closed_url ) . "'>" . __('Closed', 'dp-lang') . "</a>";
              }
              else if ($post->post_status == 'order_paid') {
                  $actions['shipped'] = "<a title='" . esc_attr(__('Mark as Shipped', 'dp-lang')) . "' href='" . esc_url( $shipped_url )  . "'>" . __('Shipped', 'dp-lang') . "</a>";
                  $actions['closed'] = "<a title='" . esc_attr(__('Mark as Closed', 'dp-lang')) . "' href='" . esc_url( $closed_url ) . "'>" . __('Closed', 'dp-lang') . "</a>";
              }
              else if ($post->post_status == 'order_shipped') {
                  $actions['closed'] = "<a title='" . esc_attr(__('Mark as Closed', 'dp-lang')) . "' href='" . esc_url( $closed_url ) . "'>" . __('Closed', 'dp-lang') . "</a>";
              }
              else if ($post->post_status == 'order_closed') {
                  $actions['received'] = "<a title='" . esc_attr(__('Mark as Received', 'dp-lang')) . "' href='" . esc_url( $received_url ) . "'>" . __('Received', 'dp-lang') . "</a>";
                  $actions['paid'] = "<a title='" . esc_attr(__('Mark as Paid', 'dp-lang')) . "' href='" . esc_url( $paid_url ) . "'>" . __('Paid', 'dp-lang') . "</a>";
                  $actions['shipped'] = "<a title='" . esc_attr(__('Mark as Shipped', 'dp-lang')) . "' href='" . esc_url( $shipped_url )  . "'>" . __('Shipped', 'dp-lang') . "</a>";
              }
        }
        return $actions;
    }

    /**
     * Action for Copying/Cloning a Product
     *
     */
    static function edit_products_copy_action() {
        $action = 'copy-duka';
        if ((isset($_GET['action'])) && ($_GET['action'] == $action)) {
            $sendback_href = remove_query_arg(array('_wpnonce', 'duka-action', 'post', 'trashed', 'untrashed', 'deleted', 'ids'), wp_get_referer());
            if (isset($_GET['post'])) $product_id = intval($_GET['post']);
            else wp_redirect($sendback_href);

            if (isset($_GET['post_type'])) $post_type = esc_attr($_GET['post_type']);
            else wp_redirect($sendback_href);

            if ((!isset($_GET['_wpnonce'])) || !wp_verify_nonce($_GET['_wpnonce'], "{$action}-{$post_type}_{$product_id}"))
              wp_redirect($sendback_href);

            $product = (array)get_post_to_edit($product_id);
            $product['ID'] = 0;
             // Zero out the Product ID to force insert of new item
            $product['post_status'] = 'draft';
            $product['post_author'] = get_current_user_id();
            $new_product_id = wp_insert_post($product);
            if (($new_product_id) && (!is_wp_error($new_product_id))) {

                //Copy the meta
                $product_meta_keys = get_post_custom_keys($product_id);
                if (!empty($product_meta_keys)) {
                    foreach ($product_meta_keys as $meta_key) {
                        $meta_values = get_post_custom_values($meta_key, $product_id);

                        foreach ($meta_values as $meta_value) {
                            $meta_value = maybe_unserialize($meta_value);
                            add_post_meta($new_product_id, $meta_key, $meta_value);
                        }
                    }
                }

                //Copy the taxonomy terms
                $product_taxonomies = get_object_taxonomies($post_type);
                if (!empty($product_taxonomies)) {
                    foreach ($product_taxonomies as $product_taxonomy) {
                        $product_terms = wp_get_object_terms($product_id, $product_taxonomy, array('orderby' => 'term_order'));
                        if (($product_terms) && (count($product_terms))) {
                            $terms = array();
                            foreach ($product_terms as $product_term) $terms[] = $product_term->slug;
                        }
                        wp_set_object_terms($new_product_id, $terms, $product_taxonomy);
                    }
                }
            }
        }
        wp_redirect($sendback_href);
        die();
    }

    /**
     * Columns for Orders
     *
     */
    static function manage_orders_columns($old_columns) {
        global $post_status;

        $columns['cb'] = '<input type="checkbox" />';
        
        $columns['duka_orders_id'] = __('Order ID', 'dp-lang');
        $columns['duka_orders_status'] = __('Status', 'dp-lang');
        $columns['duka_orders_date'] = __('Order Date', 'dp-lang');
        $columns['duka_orders_name'] = __('From', 'dp-lang');
        $columns['duka_orders_items'] = __('Items', 'dp-lang');
        $columns['duka_orders_shipping'] = __('Shipping', 'dp-lang');
        $columns['duka_orders_tax'] = __('Tax', 'dp-lang');
        $columns['duka_orders_discount'] = __('Discount', 'dp-lang');
        $columns['duka_orders_total'] = __('Total', 'dp-lang');

        return $columns;
    }

    /**
     * Custom Column Content for Orders
     *
     */
     static function manage_orders_custom_columns($column) {
        global $post,$dukapress;
        $meta = get_post_custom();

        //unserialize
        foreach ($meta as $key => $val)
            $meta[$key] = array_map('maybe_unserialize', $val);

        switch ($column) {
          case "duka_orders_status":
              if ($post->post_status == 'order_received')
                $text = __('Received', 'dp-lang');
              else if ($post->post_status == 'order_paid')
                $text = __('Paid', 'dp-lang');
              else if ($post->post_status == 'order_shipped')
                $text = __('Shipped', 'dp-lang');
              else if ($post->post_status == 'order_closed')
                $text = __('Closed', 'dp-lang');
              else if ($post->post_status == 'trash')
                $text = __('Trashed', 'dp-lang');
              else
                $text = __('Received', 'dp-lang');
                
              edit_post_link($text, '<a class="duka_orders_status">', '</a>',$post->ID);
              break;

          case "duka_orders_date":
              $t_time = get_the_time(__('Y/m/d g:i:s A'));
              $m_time = $post->post_date;
              $time = get_post_time('G', true, $post);

              $time_diff = time() - $time;

              if ($time_diff > 0 && $time_diff < 24 * 60 * 60) $h_time = sprintf(__('%s ago'), human_time_diff($time));
              else $h_time = mysql2date(__('Y/m/d'), $m_time);
              echo '<abbr title="' . $t_time . '">' . $h_time . '</abbr>';
              break;

          case "duka_orders_id":
              $title = _draft_or_post_title();
              edit_post_link($title, '<a class="row-title">', '</a>',$post->ID);
              break;

          case "duka_orders_name":
                if(isset($meta["dpsc_user_info"][0])){
					$fnames = "";
                    $em = "";
                    $firstname =  array_search('dpsc_firstname', array_column($meta["dpsc_user_info"][0], 'uname'));
					if($firstname !== FALSE ){
                        $fnames = $meta["dpsc_user_info"][0][$firstname]['value'];
                    }
                    $lastname =  array_search('dpsc_lastname', array_column($meta["dpsc_user_info"][0], 'uname'));
					if($lastname !== FALSE ){
                        $fnames  .= " ".$meta["dpsc_user_info"][0][$lastname]['value'];
                    }
                    $email =  array_search('dpsc_email', array_column($meta["dpsc_user_info"][0], 'uname'));
                    if($email !== FALSE ){
                        $em = $meta["dpsc_user_info"][0][$email]['value'];
                    }
                    echo esc_attr($fnames) . ' (<a href="mailto:' . urlencode($fnames) . ' &lt;' . esc_attr($em) . '&gt;?subject=' . urlencode(sprintf(__('Regarding Your Order (%s)', 'dp-lang'), $post->post_title)) . '">' . esc_attr($em) . '</a>)';
                }else
                    _e('N/A', 'dp-lang');
              break;

          case "duka_orders_items":
              echo number_format_i18n($meta["duka_order_items"][0]);
              break;

          case "duka_orders_shipping":
                if(isset($meta["duka_shipping_total"]))
                    echo $dukapress->format_currency('', $meta["duka_shipping_total"][0]);
                else
                    _e('N/A', 'dp-lang');
              break;

          case "duka_orders_tax":
              echo $dukapress->format_currency('', $meta["duka_tax_total"][0]);
              break;

          case "duka_orders_discount":
              if (isset($meta["duka_discount_info"][0]) && $meta["duka_discount_info"][0]) {
                  echo $dukapress->format_currency('',$meta["duka_discount_info"][0]['discount']) . ' (' . $meta["duka_discount_info"][0]['code'] . ')';
              }
              else {
                  _e('N/A', 'dp-lang');
              }
              break;

          case "duka_orders_total":
				$items = number_format_i18n($meta["duka_order_items"][0]);
				$price = $meta["duka_order_total"][0];
				echo $dukapress->format_currency('', $items * $price );
				if($meta["dpsc_payment_info"]){
					echo "<br/><span style='color: #999'>".$meta["dpsc_payment_info"][0]['name']."</span>";
				}
				break;
          }
      }
}
?>
