<?php
class Dukapress_PostTypes{

	static function init(){
		add_action('init', array(__CLASS__, 'register_post_types'), 0);
        add_filter('manage_edit-duka_variation_columns',  array(__CLASS__, 'remove_variation_columns'));
	}
	/**
    * Register the custom post types that we will be using
    * @since 2.6
    */
    static function register_post_types() {
		global $wp_version;
		global $dukapress;

      // Register product categories
      register_taxonomy('duka_category',
      	'duka',
      	apply_filters('dukapress_register_product_category',
      		array(
      			'hierarchical' => true,
      			'label' => __('Product Categories', 'dp-lang'),
      			'singular_label' => __('Product Category', 'dp-lang'),
      			'rewrite' => array('with_front' => false, 'slug' => $dukapress->get_setting('slugs->products') . '/' . $dukapress->get_setting('slugs->category'))
      			)
      		)
      	);

      // Register product tags
      register_taxonomy('duka_tag',
      	'duka',
      	apply_filters('dukapress_register_product_tag',
      		array(
      			'hierarchical' => false,
      			'label' => __('Product Tags', 'dp-lang'),
      			'singular_label' => __('Product Tag', 'dp-lang'),
      			'rewrite' => array('with_front' => false, 'slug' => $dukapress->get_setting('slugs->products') . '/' . $dukapress->get_setting('slugs->tag'))
      			)
      		)
        );
      
      
      // Register product variations
      register_taxonomy('duka_variation',
      	'duka',
      	apply_filters('dukapress_register_product_variation',
      		array(
                'labels' => array(
                    'name' => _x( 'Variations', 'taxonomy general name' ),
                    'singular_name' => _x( 'Variation', 'taxonomy singular name' ),
                    'search_items' =>  __( 'Search Variations' ,'dp-lang'),
                    'all_items' => __( 'All Variations' ,'dp-lang'),
                    'edit_item' => __( 'Edit Variation' ,'dp-lang'), 
                    'update_item' => __( 'Update Variation' ,'dp-lang'),
                    'add_new_item' => __( 'Add Variation' ,'dp-lang'),
                    'new_item_name' => __( 'New Variation' ,'dp-lang')
                ),
      			'hierarchical' => false,
      			'label' => __('Variations', 'dp-lang'),
      			'singular_label' => __('Variation', 'dp-lang'),
      			'rewrite' => false,
                'meta_box_cb' => false,
                'publicly_queryable' => false
      			)
      		)
        );

      $icon = version_compare($wp_version, '3.8', '>=') ? DPSC_DUKAPRESS_RESOURCEURL . '/img/dp_icon_white.png' : DPSC_DUKAPRESS_RESOURCEURL . '/img/dp_icon.png';

      // Register custom duka post type
      register_post_type('duka',
      	apply_filters('dukapress_register_post_type',
      		array(
      			'labels' => array(
      				'name' => __('Products', 'dp-lang'),
      				'singular_name' => __('Product', 'dp-lang'),
      				'menu_name' => __('Products', 'dp-lang'),
      				'all_items' => __('Products', 'dp-lang'),
      				'add_new' => __('Create New', 'dp-lang'),
      				'add_new_item' => __('Create New Product', 'dp-lang'),
      				'edit_item' => __('Edit Product', 'dp-lang'),
      				'edit' => __('Edit', 'dp-lang'),
      				'new_item' => __('New Product', 'dp-lang'),
      				'view_item' => __('View Product', 'dp-lang'),
      				'search_items' => __('Search Products', 'dp-lang'),
      				'not_found' => __('No Products Found', 'dp-lang'),
      				'not_found_in_trash' => __('No Products found in Trash', 'dp-lang'),
      				'view' => __('View Product', 'dp-lang')
      				),
      			'description' => __('Products for your e-commerce store.', 'dp-lang'),
      			'public' => true,
      			'show_ui' => true,
      			'publicly_queryable' => true,
      			'capability_type' => 'page',
      			'hierarchical' => false,
      			'menu_icon' => $icon,
      			'rewrite' => array('slug' => $dukapress->get_setting('slugs->products'), 'with_front' => false),
      			'query_var' => true,
      			'supports' => array('title', 'editor', 'author', 'excerpt', 'revisions', 'thumbnail',),
      			'taxonomies' => array('duka_category', 'duka_tag')
      			)
			)
		);

      //Post status
      register_post_status('out_of_stock',
      	array(
      		'label' => __('Out of Stock', 'dp-lang'),
      		'label_count' => _n_noop(__('Out of Stock <span class="count">(%s)</span>', 'dp-lang'), __('Out of Stock <span class="count">(%s)</span>', 'dp-lang')),
      		'post_type' => 'duka',
      		'public' => false
      		)
      	);

      //register the orders post type
      register_post_type('duka_order',
      	apply_filters('dukapress_register_post_type_duka_order',
      		array(
      			'labels' => array(
      				'name' => __('Orders', 'dp-lang'),
      				'singular_name' => __('Order', 'dp-lang'),
      				'edit' => __('View', 'dp-lang'),
                    'edit_item' => __('Order Details', 'dp-lang'),
      				'view_item' => __('View Order', 'dp-lang'),
      				'search_items' => __('Search Orders', 'dp-lang'),
      				'not_found' => __('No Orders Found', 'dp-lang')
      			),
      			'description' => __('Orders from your e-commerce store.', 'dp-lang'),
      			'public' => false,
      			'show_ui' => true,
      			'capability_type' => 'page',
      			'hierarchical' => false,
      			'rewrite' => false,
      			'query_var' => false,
      			'supports' => false,
				'show_in_menu' => 'edit.php?post_type=duka',
      			'capabilities' => array(
          			'create_posts' => false, // Removes support for the "Add New" function ( use 'do_not_allow' instead of false for multisite set ups )
       			),
        			'map_meta_cap' => true,
      			)
      		)
      	);

        //register custom post statuses for our orders
		register_post_status( 'order_received', array(
			'label'                     => _x( 'Received', 'dp-lang' ),
            'post_type'					 => 'duka_order',
			'public'                    => true,
			'exclude_from_search'       => false,
			'show_in_admin_all_list'    => false,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Received <span class="count">(%s)</span>', 'Received <span class="count">(%s)</span>' ),
		) );
		
		register_post_status( 'order_paid', array(
			'label'                     => _x( 'Paid', 'dp-lang' ),
            'post_type'					 => 'duka_order',
			'public'                    => true,
			'exclude_from_search'       => false,
			'show_in_admin_all_list'    => false,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Paid <span class="count">(%s)</span>', 'Paid <span class="count">(%s)</span>' ),
		) );
	
	
		register_post_status( 'order_shipped', array(
			'label'                     => _x( 'Shipped', 'dp-lang' ),
            'post_type'					 => 'duka_order',
			'public'                    => true,
			'exclude_from_search'       => false,
			'show_in_admin_all_list'    => false,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Shipped <span class="count">(%s)</span>', 'Shipped <span class="count">(%s)</span>' ),
		) );
		
		register_post_status( 'order_closed', array(
			'label'                     => _x( 'Closed', 'dp-lang' ),
            'post_type'					 => 'duka_order',
			'public'                    => true,
			'exclude_from_search'       => false,
			'show_in_admin_all_list'    => false,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Closed <span class="count">(%s)</span>', 'Closed <span class="count">(%s)</span>' ),
		) );
      
        register_post_status( 'order_cancelled', array(
			'label'                     => _x( 'Cancelled', 'dp-lang' ),
            'post_type'					 => 'duka_order',
			'public'                    => true,
			'exclude_from_search'       => false,
			'show_in_admin_all_list'    => false,
			'show_in_admin_status_list' => true,
			'label_count'               => _n_noop( 'Cancelled <span class="count">(%s)</span>', 'Cancelled <span class="count">(%s)</span>' ),
		) );

		register_post_status( 'trash', array(
			'label'						 => _x( 'Trash', 'post' ),
			'label_count'				 => _n_noop( 'Trash <span class="count">(%s)</span>', 'Trash <span class="count">(%s)</span>' ),
			'show_in_admin_status_list'	 => true,
			'post_type'					 => 'duka_order',
			'public'					 => false
		) );
    }
    
    /**
     * Remove the variation columns we dont need
     *
     */
    static function remove_variation_columns($columns){
        unset($columns['slug']);
        unset($columns['posts']);
        return $columns;
    }
}
?>
